// Generated by the protocol buffer compiler.  DO NOT EDIT!
// NO CHECKED-IN PROTOBUF GENCODE
// source: alarm/v1/config.proto
// Protobuf C++ Version: 7.35.1

#include "alarm/v1/config.pb.h"

#include <algorithm>
#include <type_traits>
#include "google/protobuf/io/coded_stream.h"
#include "google/protobuf/generated_message_tctable_impl.h"
#include "google/protobuf/internal_visibility.h"
#include "google/protobuf/extension_set.h"
#include "google/protobuf/generated_message_util.h"
#include "google/protobuf/wire_format_lite.h"
#include "google/protobuf/descriptor.h"
#include "google/protobuf/generated_message_reflection.h"
#include "google/protobuf/reflection_ops.h"
#include "google/protobuf/wire_format.h"
// @@protoc_insertion_point(includes)

// Must be included last.
#include "google/protobuf/port_def.inc"
PROTOBUF_PRAGMA_INIT_SEG
namespace _pb = ::google::protobuf;
namespace _pbi = ::google::protobuf::internal;
namespace _fl = ::google::protobuf::internal::field_layout;
#ifdef PROTOBUF_MESSAGE_GLOBALS
namespace {
PROTOBUF_CONSTINIT ::google::protobuf::internal::ReflectionData
    file_reflection_data[] = {
        // ::alarms::v1::SendAlarmConfiguration
        {&::_pbi::kDescriptorMethods, &::descriptor_table_alarm_2fv1_2fconfig_2eproto, /* tracker*/ nullptr,},
        // ::alarms::v1::ProvideAlarmConfiguration
        {&::_pbi::kDescriptorMethods, &::descriptor_table_alarm_2fv1_2fconfig_2eproto, /* tracker*/ nullptr,},
        // ::alarms::v1::AlarmConfiguration
        {&::_pbi::kDescriptorMethods, &::descriptor_table_alarm_2fv1_2fconfig_2eproto, /* tracker*/ nullptr,},
};
}  // namespace
#endif
namespace alarms {
namespace v1 {
class SendAlarmConfiguration::_Internal {
 public:
  using HasBits = decltype(::std::declval<SendAlarmConfiguration>()._impl_._has_bits_);
  static constexpr ::int32_t kHasBitsOffset =
      8 * PROTOBUF_FIELD_OFFSET(SendAlarmConfiguration, _impl_._has_bits_);
};

constexpr SendAlarmConfiguration::ParseTableT_ SendAlarmConfiguration::InternalGenerateParseTable_(const ::_pbi::ClassData* class_data) {
  return ParseTableT_{
    {
      PROTOBUF_FIELD_OFFSET(SendAlarmConfiguration, _impl_._has_bits_),
      0, // no _extensions_
      1, 0,  // max_field_number, fast_idx_mask
      offsetof(ParseTableT_, field_lookup_table),
      4294967294,  // skipmap
      offsetof(ParseTableT_, field_entries),
      1,  // num_field_entries
      0,  // num_aux_entries
      offsetof(ParseTableT_, field_names),  // no aux_entries
      class_data,
      nullptr,  // post_loop_handler
      ::_pbi::TcParser::GenericFallback,  // fallback
      #ifdef PROTOBUF_PREFETCH_PARSE_TABLE
      ::_pbi::TcParser::GetTable<::alarms::v1::SendAlarmConfiguration>(),  // to_prefetch
      #endif  // PROTOBUF_PREFETCH_PARSE_TABLE
    }, {{
      // string config_hash = 1;
      {::_pbi::TcParser::FastUS1,
       {10, 0, 0,
        PROTOBUF_FIELD_OFFSET(SendAlarmConfiguration, _impl_.config_hash_)}},
    }}, {{
      65535, 65535
    }}, {{
      // string config_hash = 1;
      {PROTOBUF_FIELD_OFFSET(SendAlarmConfiguration, _impl_.config_hash_), _Internal::kHasBitsOffset + 0, 0, (0 | ::_fl::kFcOptional | ::_fl::kUtf8String | ::_fl::kRepAString)},
    }},
    // no aux_entries
    {{
      "\40\13\0\0\0\0\0\0"
      "alarms.v1.SendAlarmConfiguration"
      "config_hash"
    }},
  };
}


inline constexpr SendAlarmConfiguration::Impl_::Impl_(
    [[maybe_unused]] ::google::protobuf::internal::InternalVisibility visibility,
    ::_pbi::ConstantInitialized) noexcept
      : _cached_size_{0},
        config_hash_(
            &::google::protobuf::internal::fixed_address_empty_string,
            ::_pbi::ConstantInitialized()) {}

template <typename>
constexpr SendAlarmConfiguration::SendAlarmConfiguration(::_pbi::ConstantInitialized,
                       const ::_pbi::ClassData* PROTOBUF_NONNULL class_data)
    : ::google::protobuf::Message(
#if defined(PROTOBUF_CUSTOM_VTABLE)
          class_data
#endif  // PROTOBUF_CUSTOM_VTABLE
          ),
      _impl_(internal_visibility(), ::_pbi::ConstantInitialized()) {
}
inline void* PROTOBUF_NONNULL SendAlarmConfiguration::PlacementNew_(
    const void* PROTOBUF_NONNULL, void* PROTOBUF_NONNULL mem,
    ::google::protobuf::Arena* PROTOBUF_NULLABLE arena) {
  return ::new (mem) SendAlarmConfiguration(arena);
}
constexpr auto SendAlarmConfiguration::InternalNewImpl_() {
  return ::google::protobuf::internal::MessageCreator::CopyInit(sizeof(SendAlarmConfiguration), alignof(SendAlarmConfiguration));
}
constexpr auto SendAlarmConfiguration::InternalGenerateClassData_(
    const MessageLite& prototype,
    const ::google::protobuf::internal::TcParseTableBase* tc_table) {
  return ::google::protobuf::internal::ClassDataFull{
      ::google::protobuf::internal::ClassData{
          &prototype,
#ifndef PROTOBUF_MESSAGE_GLOBALS
          &_table_.header,
#else
          tc_table,
#endif
          nullptr,  // IsInitialized
          &SendAlarmConfiguration::MergeImpl,
          ::google::protobuf::Message::GetNewImpl<SendAlarmConfiguration>(),
#if defined(PROTOBUF_CUSTOM_VTABLE)
          &SendAlarmConfiguration::SharedDtor,
          ::google::protobuf::Message::GetClearImpl<SendAlarmConfiguration>(), &SendAlarmConfiguration::ByteSizeLong,
              &SendAlarmConfiguration::_InternalSerialize,
#endif  // PROTOBUF_CUSTOM_VTABLE
          PROTOBUF_FIELD_OFFSET(SendAlarmConfiguration, _impl_._cached_size_),
          false,
      },
#ifdef PROTOBUF_MESSAGE_GLOBALS
      &file_reflection_data[0],
#else   // !PROTOBUF_MESSAGE_GLOBALS
      &::_pbi::kDescriptorMethods,
      &descriptor_table_alarm_2fv1_2fconfig_2eproto,
      nullptr,  // tracker
#endif  // PROTOBUF_MESSAGE_GLOBALS
  };
}
struct SendAlarmConfigurationGlobalsTypeInternal : ::_pbi::MessageGlobalsBase {
  constexpr SendAlarmConfigurationGlobalsTypeInternal()
      :
#ifndef PROTOBUF_MESSAGE_GLOBALS
        _default(::_pbi::ConstantInitialized{},
                 SendAlarmConfiguration_class_data_.base())
#else   // !PROTOBUF_MESSAGE_GLOBALS
        MessageGlobalsBase(SendAlarmConfiguration::InternalGenerateClassData_(
            _default, &SendAlarmConfiguration_globals_._table.header)),
        _default(::_pbi::ConstantInitialized{}, GetClassData()),
        _table(::_pbi::PrivateAccess::GenerateParseTable<SendAlarmConfiguration>(
            GetClassData()))
#endif  // PROTOBUF_MESSAGE_GLOBALS
  {
  }
  ~SendAlarmConfigurationGlobalsTypeInternal() {}
  union {
    alignas(::_pbi::kMaxMessageAlignment) SendAlarmConfiguration _default;
  };
#ifdef PROTOBUF_MESSAGE_GLOBALS
  decltype(::_pbi::PrivateAccess::GenerateParseTable<SendAlarmConfiguration>(
      ::std::declval<const ::_pbi::ClassData*>())) _table;
#endif
};
#ifdef PROTOBUF_MESSAGE_GLOBALS
static_assert(PROTOBUF_FIELD_OFFSET(SendAlarmConfigurationGlobalsTypeInternal, _default) ==
              ::_pbi::MessageGlobalsBase::OffsetToDefault());
#endif  // PROTOBUF_MESSAGE_GLOBALS

PROTOBUF_ATTRIBUTE_NO_DESTROY PROTOBUF_CONSTINIT
    PROTOBUF_ATTRIBUTE_INIT_PRIORITY1 PROTOBUF_MESSAGE_GLOBALS_CONST SendAlarmConfigurationGlobalsTypeInternal SendAlarmConfiguration_globals_
        PROTOBUF_MESSAGE_GLOBALS_SECTION(.data.rel.ro);
#if defined(PROTOBUF_CUSTOM_VTABLE)
namespace {
const ::_pbi::ClassData* SendAlarmConfiguration_get_class_data() {
#ifdef PROTOBUF_MESSAGE_GLOBALS
  return SendAlarmConfiguration_globals_.GetClassData();
#else
  return SendAlarmConfiguration_class_data_.base();
#endif  // PROTOBUF_MESSAGE_GLOBALS
}
}  // namespace
#endif  // PROTOBUF_CUSTOM_VTABLE
class AlarmConfiguration::_Internal {
 public:
  using HasBits = decltype(::std::declval<AlarmConfiguration>()._impl_._has_bits_);
  static constexpr ::int32_t kHasBitsOffset =
      8 * PROTOBUF_FIELD_OFFSET(AlarmConfiguration, _impl_._has_bits_);
};

constexpr AlarmConfiguration::ParseTableT_ AlarmConfiguration::InternalGenerateParseTable_(const ::_pbi::ClassData* class_data) {
  return ParseTableT_{
    {
      PROTOBUF_FIELD_OFFSET(AlarmConfiguration, _impl_._has_bits_),
      0, // no _extensions_
      35, 248,  // max_field_number, fast_idx_mask
      offsetof(ParseTableT_, field_lookup_table),
      0,  // skipmap
      offsetof(ParseTableT_, field_entries),
      35,  // num_field_entries
      0,  // num_aux_entries
      offsetof(ParseTableT_, field_names),  // no aux_entries
      class_data,
      nullptr,  // post_loop_handler
      ::_pbi::TcParser::GenericFallback,  // fallback
      #ifdef PROTOBUF_PREFETCH_PARSE_TABLE
      ::_pbi::TcParser::GetTable<::alarms::v1::AlarmConfiguration>(),  // to_prefetch
      #endif  // PROTOBUF_PREFETCH_PARSE_TABLE
    }, {{
      {::_pbi::TcParser::MiniParse, {}},
      // string alarm = 1;
      {::_pbi::TcParser::FastUS1,
       {10, 0, 0,
        PROTOBUF_FIELD_OFFSET(AlarmConfiguration, _impl_.alarm_)}},
      // string template = 2;
      {::_pbi::TcParser::FastUS1,
       {18, 1, 0,
        PROTOBUF_FIELD_OFFSET(AlarmConfiguration, _impl_.template__)}},
      // string on_chart = 3;
      {::_pbi::TcParser::FastUS1,
       {26, 2, 0,
        PROTOBUF_FIELD_OFFSET(AlarmConfiguration, _impl_.on_chart_)}},
      // string classification = 4;
      {::_pbi::TcParser::FastUS1,
       {34, 3, 0,
        PROTOBUF_FIELD_OFFSET(AlarmConfiguration, _impl_.classification_)}},
      // string type = 5;
      {::_pbi::TcParser::FastUS1,
       {42, 4, 0,
        PROTOBUF_FIELD_OFFSET(AlarmConfiguration, _impl_.type_)}},
      // string component = 6;
      {::_pbi::TcParser::FastUS1,
       {50, 5, 0,
        PROTOBUF_FIELD_OFFSET(AlarmConfiguration, _impl_.component_)}},
      // string os = 7;
      {::_pbi::TcParser::FastUS1,
       {58, 6, 0,
        PROTOBUF_FIELD_OFFSET(AlarmConfiguration, _impl_.os_)}},
      // string hosts = 8;
      {::_pbi::TcParser::FastUS1,
       {66, 7, 0,
        PROTOBUF_FIELD_OFFSET(AlarmConfiguration, _impl_.hosts_)}},
      // string plugin = 9;
      {::_pbi::TcParser::FastUS1,
       {74, 8, 0,
        PROTOBUF_FIELD_OFFSET(AlarmConfiguration, _impl_.plugin_)}},
      // string module = 10;
      {::_pbi::TcParser::FastUS1,
       {82, 9, 0,
        PROTOBUF_FIELD_OFFSET(AlarmConfiguration, _impl_.module_)}},
      // string charts = 11;
      {::_pbi::TcParser::FastUS1,
       {90, 10, 0,
        PROTOBUF_FIELD_OFFSET(AlarmConfiguration, _impl_.charts_)}},
      // string families = 12 [deprecated = true];
      {::_pbi::TcParser::FastUS1,
       {98, 11, 0,
        PROTOBUF_FIELD_OFFSET(AlarmConfiguration, _impl_.families_)}},
      // string lookup = 13;
      {::_pbi::TcParser::FastUS1,
       {106, 12, 0,
        PROTOBUF_FIELD_OFFSET(AlarmConfiguration, _impl_.lookup_)}},
      // string every = 14;
      {::_pbi::TcParser::FastUS1,
       {114, 13, 0,
        PROTOBUF_FIELD_OFFSET(AlarmConfiguration, _impl_.every_)}},
      // string units = 15;
      {::_pbi::TcParser::FastUS1,
       {122, 14, 0,
        PROTOBUF_FIELD_OFFSET(AlarmConfiguration, _impl_.units_)}},
      // string green = 16;
      {::_pbi::TcParser::FastUS2,
       {386, 15, 0,
        PROTOBUF_FIELD_OFFSET(AlarmConfiguration, _impl_.green_)}},
      // string red = 17;
      {::_pbi::TcParser::FastUS2,
       {394, 16, 0,
        PROTOBUF_FIELD_OFFSET(AlarmConfiguration, _impl_.red_)}},
      // string calculation_expr = 18;
      {::_pbi::TcParser::FastUS2,
       {402, 17, 0,
        PROTOBUF_FIELD_OFFSET(AlarmConfiguration, _impl_.calculation_expr_)}},
      // string warning_expr = 19;
      {::_pbi::TcParser::FastUS2,
       {410, 18, 0,
        PROTOBUF_FIELD_OFFSET(AlarmConfiguration, _impl_.warning_expr_)}},
      // string critical_expr = 20;
      {::_pbi::TcParser::FastUS2,
       {418, 19, 0,
        PROTOBUF_FIELD_OFFSET(AlarmConfiguration, _impl_.critical_expr_)}},
      // string recipient = 21;
      {::_pbi::TcParser::FastUS2,
       {426, 20, 0,
        PROTOBUF_FIELD_OFFSET(AlarmConfiguration, _impl_.recipient_)}},
      // string exec = 22;
      {::_pbi::TcParser::FastUS2,
       {434, 21, 0,
        PROTOBUF_FIELD_OFFSET(AlarmConfiguration, _impl_.exec_)}},
      // string delay = 23;
      {::_pbi::TcParser::FastUS2,
       {442, 22, 0,
        PROTOBUF_FIELD_OFFSET(AlarmConfiguration, _impl_.delay_)}},
      // string repeat = 24;
      {::_pbi::TcParser::FastUS2,
       {450, 23, 0,
        PROTOBUF_FIELD_OFFSET(AlarmConfiguration, _impl_.repeat_)}},
      // string info = 25;
      {::_pbi::TcParser::FastUS2,
       {458, 24, 0,
        PROTOBUF_FIELD_OFFSET(AlarmConfiguration, _impl_.info_)}},
      // string options = 26;
      {::_pbi::TcParser::FastUS2,
       {466, 25, 0,
        PROTOBUF_FIELD_OFFSET(AlarmConfiguration, _impl_.options_)}},
      // string host_labels = 27;
      {::_pbi::TcParser::FastUS2,
       {474, 26, 0,
        PROTOBUF_FIELD_OFFSET(AlarmConfiguration, _impl_.host_labels_)}},
      // int32 p_db_lookup_after = 28;
      {::_pbi::TcParser::FastV32S2,
       {480, 29, 0,
        PROTOBUF_FIELD_OFFSET(AlarmConfiguration, _impl_.p_db_lookup_after_)}},
      // int32 p_db_lookup_before = 29;
      {::_pbi::TcParser::FastV32S2,
       {488, 30, 0,
        PROTOBUF_FIELD_OFFSET(AlarmConfiguration, _impl_.p_db_lookup_before_)}},
      // string p_db_lookup_dimensions = 30;
      {::_pbi::TcParser::FastUS2,
       {498, 27, 0,
        PROTOBUF_FIELD_OFFSET(AlarmConfiguration, _impl_.p_db_lookup_dimensions_)}},
      // string p_db_lookup_method = 31;
      {::_pbi::TcParser::FastUS2,
       {506, 28, 0,
        PROTOBUF_FIELD_OFFSET(AlarmConfiguration, _impl_.p_db_lookup_method_)}},
    }}, {{
      33, 0, 1,
      65528, 32,
      65535, 65535
    }}, {{
      // string alarm = 1;
      {PROTOBUF_FIELD_OFFSET(AlarmConfiguration, _impl_.alarm_), _Internal::kHasBitsOffset + 0, 0, (0 | ::_fl::kFcOptional | ::_fl::kUtf8String | ::_fl::kRepAString)},
      // string template = 2;
      {PROTOBUF_FIELD_OFFSET(AlarmConfiguration, _impl_.template__), _Internal::kHasBitsOffset + 1, 0, (0 | ::_fl::kFcOptional | ::_fl::kUtf8String | ::_fl::kRepAString)},
      // string on_chart = 3;
      {PROTOBUF_FIELD_OFFSET(AlarmConfiguration, _impl_.on_chart_), _Internal::kHasBitsOffset + 2, 0, (0 | ::_fl::kFcOptional | ::_fl::kUtf8String | ::_fl::kRepAString)},
      // string classification = 4;
      {PROTOBUF_FIELD_OFFSET(AlarmConfiguration, _impl_.classification_), _Internal::kHasBitsOffset + 3, 0, (0 | ::_fl::kFcOptional | ::_fl::kUtf8String | ::_fl::kRepAString)},
      // string type = 5;
      {PROTOBUF_FIELD_OFFSET(AlarmConfiguration, _impl_.type_), _Internal::kHasBitsOffset + 4, 0, (0 | ::_fl::kFcOptional | ::_fl::kUtf8String | ::_fl::kRepAString)},
      // string component = 6;
      {PROTOBUF_FIELD_OFFSET(AlarmConfiguration, _impl_.component_), _Internal::kHasBitsOffset + 5, 0, (0 | ::_fl::kFcOptional | ::_fl::kUtf8String | ::_fl::kRepAString)},
      // string os = 7;
      {PROTOBUF_FIELD_OFFSET(AlarmConfiguration, _impl_.os_), _Internal::kHasBitsOffset + 6, 0, (0 | ::_fl::kFcOptional | ::_fl::kUtf8String | ::_fl::kRepAString)},
      // string hosts = 8;
      {PROTOBUF_FIELD_OFFSET(AlarmConfiguration, _impl_.hosts_), _Internal::kHasBitsOffset + 7, 0, (0 | ::_fl::kFcOptional | ::_fl::kUtf8String | ::_fl::kRepAString)},
      // string plugin = 9;
      {PROTOBUF_FIELD_OFFSET(AlarmConfiguration, _impl_.plugin_), _Internal::kHasBitsOffset + 8, 0, (0 | ::_fl::kFcOptional | ::_fl::kUtf8String | ::_fl::kRepAString)},
      // string module = 10;
      {PROTOBUF_FIELD_OFFSET(AlarmConfiguration, _impl_.module_), _Internal::kHasBitsOffset + 9, 0, (0 | ::_fl::kFcOptional | ::_fl::kUtf8String | ::_fl::kRepAString)},
      // string charts = 11;
      {PROTOBUF_FIELD_OFFSET(AlarmConfiguration, _impl_.charts_), _Internal::kHasBitsOffset + 10, 0, (0 | ::_fl::kFcOptional | ::_fl::kUtf8String | ::_fl::kRepAString)},
      // string families = 12 [deprecated = true];
      {PROTOBUF_FIELD_OFFSET(AlarmConfiguration, _impl_.families_), _Internal::kHasBitsOffset + 11, 0, (0 | ::_fl::kFcOptional | ::_fl::kUtf8String | ::_fl::kRepAString)},
      // string lookup = 13;
      {PROTOBUF_FIELD_OFFSET(AlarmConfiguration, _impl_.lookup_), _Internal::kHasBitsOffset + 12, 0, (0 | ::_fl::kFcOptional | ::_fl::kUtf8String | ::_fl::kRepAString)},
      // string every = 14;
      {PROTOBUF_FIELD_OFFSET(AlarmConfiguration, _impl_.every_), _Internal::kHasBitsOffset + 13, 0, (0 | ::_fl::kFcOptional | ::_fl::kUtf8String | ::_fl::kRepAString)},
      // string units = 15;
      {PROTOBUF_FIELD_OFFSET(AlarmConfiguration, _impl_.units_), _Internal::kHasBitsOffset + 14, 0, (0 | ::_fl::kFcOptional | ::_fl::kUtf8String | ::_fl::kRepAString)},
      // string green = 16;
      {PROTOBUF_FIELD_OFFSET(AlarmConfiguration, _impl_.green_), _Internal::kHasBitsOffset + 15, 0, (0 | ::_fl::kFcOptional | ::_fl::kUtf8String | ::_fl::kRepAString)},
      // string red = 17;
      {PROTOBUF_FIELD_OFFSET(AlarmConfiguration, _impl_.red_), _Internal::kHasBitsOffset + 16, 0, (0 | ::_fl::kFcOptional | ::_fl::kUtf8String | ::_fl::kRepAString)},
      // string calculation_expr = 18;
      {PROTOBUF_FIELD_OFFSET(AlarmConfiguration, _impl_.calculation_expr_), _Internal::kHasBitsOffset + 17, 0, (0 | ::_fl::kFcOptional | ::_fl::kUtf8String | ::_fl::kRepAString)},
      // string warning_expr = 19;
      {PROTOBUF_FIELD_OFFSET(AlarmConfiguration, _impl_.warning_expr_), _Internal::kHasBitsOffset + 18, 0, (0 | ::_fl::kFcOptional | ::_fl::kUtf8String | ::_fl::kRepAString)},
      // string critical_expr = 20;
      {PROTOBUF_FIELD_OFFSET(AlarmConfiguration, _impl_.critical_expr_), _Internal::kHasBitsOffset + 19, 0, (0 | ::_fl::kFcOptional | ::_fl::kUtf8String | ::_fl::kRepAString)},
      // string recipient = 21;
      {PROTOBUF_FIELD_OFFSET(AlarmConfiguration, _impl_.recipient_), _Internal::kHasBitsOffset + 20, 0, (0 | ::_fl::kFcOptional | ::_fl::kUtf8String | ::_fl::kRepAString)},
      // string exec = 22;
      {PROTOBUF_FIELD_OFFSET(AlarmConfiguration, _impl_.exec_), _Internal::kHasBitsOffset + 21, 0, (0 | ::_fl::kFcOptional | ::_fl::kUtf8String | ::_fl::kRepAString)},
      // string delay = 23;
      {PROTOBUF_FIELD_OFFSET(AlarmConfiguration, _impl_.delay_), _Internal::kHasBitsOffset + 22, 0, (0 | ::_fl::kFcOptional | ::_fl::kUtf8String | ::_fl::kRepAString)},
      // string repeat = 24;
      {PROTOBUF_FIELD_OFFSET(AlarmConfiguration, _impl_.repeat_), _Internal::kHasBitsOffset + 23, 0, (0 | ::_fl::kFcOptional | ::_fl::kUtf8String | ::_fl::kRepAString)},
      // string info = 25;
      {PROTOBUF_FIELD_OFFSET(AlarmConfiguration, _impl_.info_), _Internal::kHasBitsOffset + 24, 0, (0 | ::_fl::kFcOptional | ::_fl::kUtf8String | ::_fl::kRepAString)},
      // string options = 26;
      {PROTOBUF_FIELD_OFFSET(AlarmConfiguration, _impl_.options_), _Internal::kHasBitsOffset + 25, 0, (0 | ::_fl::kFcOptional | ::_fl::kUtf8String | ::_fl::kRepAString)},
      // string host_labels = 27;
      {PROTOBUF_FIELD_OFFSET(AlarmConfiguration, _impl_.host_labels_), _Internal::kHasBitsOffset + 26, 0, (0 | ::_fl::kFcOptional | ::_fl::kUtf8String | ::_fl::kRepAString)},
      // int32 p_db_lookup_after = 28;
      {PROTOBUF_FIELD_OFFSET(AlarmConfiguration, _impl_.p_db_lookup_after_), _Internal::kHasBitsOffset + 29, 0, (0 | ::_fl::kFcOptional | ::_fl::kInt32)},
      // int32 p_db_lookup_before = 29;
      {PROTOBUF_FIELD_OFFSET(AlarmConfiguration, _impl_.p_db_lookup_before_), _Internal::kHasBitsOffset + 30, 0, (0 | ::_fl::kFcOptional | ::_fl::kInt32)},
      // string p_db_lookup_dimensions = 30;
      {PROTOBUF_FIELD_OFFSET(AlarmConfiguration, _impl_.p_db_lookup_dimensions_), _Internal::kHasBitsOffset + 27, 0, (0 | ::_fl::kFcOptional | ::_fl::kUtf8String | ::_fl::kRepAString)},
      // string p_db_lookup_method = 31;
      {PROTOBUF_FIELD_OFFSET(AlarmConfiguration, _impl_.p_db_lookup_method_), _Internal::kHasBitsOffset + 28, 0, (0 | ::_fl::kFcOptional | ::_fl::kUtf8String | ::_fl::kRepAString)},
      // string p_db_lookup_options = 32;
      {PROTOBUF_FIELD_OFFSET(AlarmConfiguration, _impl_.p_db_lookup_options_), _Internal::kHasBitsOffset + 31, 0, (0 | ::_fl::kFcOptional | ::_fl::kUtf8String | ::_fl::kRepAString)},
      // int32 p_update_every = 33;
      {PROTOBUF_FIELD_OFFSET(AlarmConfiguration, _impl_.p_update_every_), _Internal::kHasBitsOffset + 34, 0, (0 | ::_fl::kFcOptional | ::_fl::kInt32)},
      // string chart_labels = 34;
      {PROTOBUF_FIELD_OFFSET(AlarmConfiguration, _impl_.chart_labels_), _Internal::kHasBitsOffset + 32, 0, (0 | ::_fl::kFcOptional | ::_fl::kUtf8String | ::_fl::kRepAString)},
      // string summary = 35;
      {PROTOBUF_FIELD_OFFSET(AlarmConfiguration, _impl_.summary_), _Internal::kHasBitsOffset + 33, 0, (0 | ::_fl::kFcOptional | ::_fl::kUtf8String | ::_fl::kRepAString)},
    }},
    // no aux_entries
    {{
      "\34\5\10\10\16\4\11\2\5\6\6\6\10\6\5\5\5\3\20\14\15\11\4\5\6\4\7\13\0\0\26\22\23\0\14\7\0\0\0\0"
      "alarms.v1.AlarmConfiguration"
      "alarm"
      "template"
      "on_chart"
      "classification"
      "type"
      "component"
      "os"
      "hosts"
      "plugin"
      "module"
      "charts"
      "families"
      "lookup"
      "every"
      "units"
      "green"
      "red"
      "calculation_expr"
      "warning_expr"
      "critical_expr"
      "recipient"
      "exec"
      "delay"
      "repeat"
      "info"
      "options"
      "host_labels"
      "p_db_lookup_dimensions"
      "p_db_lookup_method"
      "p_db_lookup_options"
      "chart_labels"
      "summary"
    }},
  };
}


inline constexpr AlarmConfiguration::Impl_::Impl_(
    [[maybe_unused]] ::google::protobuf::internal::InternalVisibility visibility,
    ::_pbi::ConstantInitialized) noexcept
      : _cached_size_{0},
        alarm_(
            &::google::protobuf::internal::fixed_address_empty_string,
            ::_pbi::ConstantInitialized()),
        template__(
            &::google::protobuf::internal::fixed_address_empty_string,
            ::_pbi::ConstantInitialized()),
        on_chart_(
            &::google::protobuf::internal::fixed_address_empty_string,
            ::_pbi::ConstantInitialized()),
        classification_(
            &::google::protobuf::internal::fixed_address_empty_string,
            ::_pbi::ConstantInitialized()),
        type_(
            &::google::protobuf::internal::fixed_address_empty_string,
            ::_pbi::ConstantInitialized()),
        component_(
            &::google::protobuf::internal::fixed_address_empty_string,
            ::_pbi::ConstantInitialized()),
        os_(
            &::google::protobuf::internal::fixed_address_empty_string,
            ::_pbi::ConstantInitialized()),
        hosts_(
            &::google::protobuf::internal::fixed_address_empty_string,
            ::_pbi::ConstantInitialized()),
        plugin_(
            &::google::protobuf::internal::fixed_address_empty_string,
            ::_pbi::ConstantInitialized()),
        module_(
            &::google::protobuf::internal::fixed_address_empty_string,
            ::_pbi::ConstantInitialized()),
        charts_(
            &::google::protobuf::internal::fixed_address_empty_string,
            ::_pbi::ConstantInitialized()),
        families_(
            &::google::protobuf::internal::fixed_address_empty_string,
            ::_pbi::ConstantInitialized()),
        lookup_(
            &::google::protobuf::internal::fixed_address_empty_string,
            ::_pbi::ConstantInitialized()),
        every_(
            &::google::protobuf::internal::fixed_address_empty_string,
            ::_pbi::ConstantInitialized()),
        units_(
            &::google::protobuf::internal::fixed_address_empty_string,
            ::_pbi::ConstantInitialized()),
        green_(
            &::google::protobuf::internal::fixed_address_empty_string,
            ::_pbi::ConstantInitialized()),
        red_(
            &::google::protobuf::internal::fixed_address_empty_string,
            ::_pbi::ConstantInitialized()),
        calculation_expr_(
            &::google::protobuf::internal::fixed_address_empty_string,
            ::_pbi::ConstantInitialized()),
        warning_expr_(
            &::google::protobuf::internal::fixed_address_empty_string,
            ::_pbi::ConstantInitialized()),
        critical_expr_(
            &::google::protobuf::internal::fixed_address_empty_string,
            ::_pbi::ConstantInitialized()),
        recipient_(
            &::google::protobuf::internal::fixed_address_empty_string,
            ::_pbi::ConstantInitialized()),
        exec_(
            &::google::protobuf::internal::fixed_address_empty_string,
            ::_pbi::ConstantInitialized()),
        delay_(
            &::google::protobuf::internal::fixed_address_empty_string,
            ::_pbi::ConstantInitialized()),
        repeat_(
            &::google::protobuf::internal::fixed_address_empty_string,
            ::_pbi::ConstantInitialized()),
        info_(
            &::google::protobuf::internal::fixed_address_empty_string,
            ::_pbi::ConstantInitialized()),
        options_(
            &::google::protobuf::internal::fixed_address_empty_string,
            ::_pbi::ConstantInitialized()),
        host_labels_(
            &::google::protobuf::internal::fixed_address_empty_string,
            ::_pbi::ConstantInitialized()),
        p_db_lookup_dimensions_(
            &::google::protobuf::internal::fixed_address_empty_string,
            ::_pbi::ConstantInitialized()),
        p_db_lookup_method_(
            &::google::protobuf::internal::fixed_address_empty_string,
            ::_pbi::ConstantInitialized()),
        p_db_lookup_after_{0},
        p_db_lookup_before_{0},
        p_db_lookup_options_(
            &::google::protobuf::internal::fixed_address_empty_string,
            ::_pbi::ConstantInitialized()),
        chart_labels_(
            &::google::protobuf::internal::fixed_address_empty_string,
            ::_pbi::ConstantInitialized()),
        summary_(
            &::google::protobuf::internal::fixed_address_empty_string,
            ::_pbi::ConstantInitialized()),
        p_update_every_{0} {}

template <typename>
constexpr AlarmConfiguration::AlarmConfiguration(::_pbi::ConstantInitialized,
                       const ::_pbi::ClassData* PROTOBUF_NONNULL class_data)
    : ::google::protobuf::Message(
#if defined(PROTOBUF_CUSTOM_VTABLE)
          class_data
#endif  // PROTOBUF_CUSTOM_VTABLE
          ),
      _impl_(internal_visibility(), ::_pbi::ConstantInitialized()) {
}
inline void* PROTOBUF_NONNULL AlarmConfiguration::PlacementNew_(
    const void* PROTOBUF_NONNULL, void* PROTOBUF_NONNULL mem,
    ::google::protobuf::Arena* PROTOBUF_NULLABLE arena) {
  return ::new (mem) AlarmConfiguration(arena);
}
constexpr auto AlarmConfiguration::InternalNewImpl_() {
  return ::google::protobuf::internal::MessageCreator::CopyInit(sizeof(AlarmConfiguration), alignof(AlarmConfiguration));
}
constexpr auto AlarmConfiguration::InternalGenerateClassData_(
    const MessageLite& prototype,
    const ::google::protobuf::internal::TcParseTableBase* tc_table) {
  return ::google::protobuf::internal::ClassDataFull{
      ::google::protobuf::internal::ClassData{
          &prototype,
#ifndef PROTOBUF_MESSAGE_GLOBALS
          &_table_.header,
#else
          tc_table,
#endif
          nullptr,  // IsInitialized
          &AlarmConfiguration::MergeImpl,
          ::google::protobuf::Message::GetNewImpl<AlarmConfiguration>(),
#if defined(PROTOBUF_CUSTOM_VTABLE)
          &AlarmConfiguration::SharedDtor,
          ::google::protobuf::Message::GetClearImpl<AlarmConfiguration>(), &AlarmConfiguration::ByteSizeLong,
              &AlarmConfiguration::_InternalSerialize,
#endif  // PROTOBUF_CUSTOM_VTABLE
          PROTOBUF_FIELD_OFFSET(AlarmConfiguration, _impl_._cached_size_),
          false,
      },
#ifdef PROTOBUF_MESSAGE_GLOBALS
      &file_reflection_data[2],
#else   // !PROTOBUF_MESSAGE_GLOBALS
      &::_pbi::kDescriptorMethods,
      &descriptor_table_alarm_2fv1_2fconfig_2eproto,
      nullptr,  // tracker
#endif  // PROTOBUF_MESSAGE_GLOBALS
  };
}
struct AlarmConfigurationGlobalsTypeInternal : ::_pbi::MessageGlobalsBase {
  constexpr AlarmConfigurationGlobalsTypeInternal()
      :
#ifndef PROTOBUF_MESSAGE_GLOBALS
        _default(::_pbi::ConstantInitialized{},
                 AlarmConfiguration_class_data_.base())
#else   // !PROTOBUF_MESSAGE_GLOBALS
        MessageGlobalsBase(AlarmConfiguration::InternalGenerateClassData_(
            _default, &AlarmConfiguration_globals_._table.header)),
        _default(::_pbi::ConstantInitialized{}, GetClassData()),
        _table(::_pbi::PrivateAccess::GenerateParseTable<AlarmConfiguration>(
            GetClassData()))
#endif  // PROTOBUF_MESSAGE_GLOBALS
  {
  }
  ~AlarmConfigurationGlobalsTypeInternal() {}
  union {
    alignas(::_pbi::kMaxMessageAlignment) AlarmConfiguration _default;
  };
#ifdef PROTOBUF_MESSAGE_GLOBALS
  decltype(::_pbi::PrivateAccess::GenerateParseTable<AlarmConfiguration>(
      ::std::declval<const ::_pbi::ClassData*>())) _table;
#endif
};
#ifdef PROTOBUF_MESSAGE_GLOBALS
static_assert(PROTOBUF_FIELD_OFFSET(AlarmConfigurationGlobalsTypeInternal, _default) ==
              ::_pbi::MessageGlobalsBase::OffsetToDefault());
#endif  // PROTOBUF_MESSAGE_GLOBALS

PROTOBUF_ATTRIBUTE_NO_DESTROY PROTOBUF_CONSTINIT
    PROTOBUF_ATTRIBUTE_INIT_PRIORITY1 PROTOBUF_MESSAGE_GLOBALS_CONST AlarmConfigurationGlobalsTypeInternal AlarmConfiguration_globals_
        PROTOBUF_MESSAGE_GLOBALS_SECTION(.data.rel.ro);
#if defined(PROTOBUF_CUSTOM_VTABLE)
namespace {
const ::_pbi::ClassData* AlarmConfiguration_get_class_data() {
#ifdef PROTOBUF_MESSAGE_GLOBALS
  return AlarmConfiguration_globals_.GetClassData();
#else
  return AlarmConfiguration_class_data_.base();
#endif  // PROTOBUF_MESSAGE_GLOBALS
}
}  // namespace
#endif  // PROTOBUF_CUSTOM_VTABLE
class ProvideAlarmConfiguration::_Internal {
 public:
  using HasBits = decltype(::std::declval<ProvideAlarmConfiguration>()._impl_._has_bits_);
  static constexpr ::int32_t kHasBitsOffset =
      8 * PROTOBUF_FIELD_OFFSET(ProvideAlarmConfiguration, _impl_._has_bits_);
};

constexpr ProvideAlarmConfiguration::ParseTableT_ ProvideAlarmConfiguration::InternalGenerateParseTable_(const ::_pbi::ClassData* class_data) {
  return ParseTableT_{
    {
      PROTOBUF_FIELD_OFFSET(ProvideAlarmConfiguration, _impl_._has_bits_),
      0, // no _extensions_
      2, 8,  // max_field_number, fast_idx_mask
      offsetof(ParseTableT_, field_lookup_table),
      4294967292,  // skipmap
      offsetof(ParseTableT_, field_entries),
      2,  // num_field_entries
      1,  // num_aux_entries
      offsetof(ParseTableT_, aux_entries),
      class_data,
      nullptr,  // post_loop_handler
      ::_pbi::TcParser::GenericFallback,  // fallback
      #ifdef PROTOBUF_PREFETCH_PARSE_TABLE
      ::_pbi::TcParser::GetTable<::alarms::v1::ProvideAlarmConfiguration>(),  // to_prefetch
      #endif  // PROTOBUF_PREFETCH_PARSE_TABLE
    }, {{
      // .alarms.v1.AlarmConfiguration config = 2;
      {::_pbi::TcParser::FastMtS1,
       {18, 1, 0,
        PROTOBUF_FIELD_OFFSET(ProvideAlarmConfiguration, _impl_.config_)}},
      // string config_hash = 1;
      {::_pbi::TcParser::FastUS1,
       {10, 0, 0,
        PROTOBUF_FIELD_OFFSET(ProvideAlarmConfiguration, _impl_.config_hash_)}},
    }}, {{
      65535, 65535
    }}, {{
      // string config_hash = 1;
      {PROTOBUF_FIELD_OFFSET(ProvideAlarmConfiguration, _impl_.config_hash_), _Internal::kHasBitsOffset + 0, 0, (0 | ::_fl::kFcOptional | ::_fl::kUtf8String | ::_fl::kRepAString)},
      // .alarms.v1.AlarmConfiguration config = 2;
      {PROTOBUF_FIELD_OFFSET(ProvideAlarmConfiguration, _impl_.config_), _Internal::kHasBitsOffset + 1, 0, (0 | ::_fl::kFcOptional | ::_fl::kMessage | ::_fl::kTvTable)},
    }},
    {{
        #ifndef PROTOBUF_MESSAGE_GLOBALS
        {::_pbi::TcParser::GetTable<::alarms::v1::AlarmConfiguration>()},
        #else
        {::_pbi::FieldAuxMessageGlobals(), &::alarms::v1::AlarmConfiguration_globals_},
        #endif
    }},
    {{
      "\43\13\0\0\0\0\0\0"
      "alarms.v1.ProvideAlarmConfiguration"
      "config_hash"
    }},
  };
}


inline constexpr ProvideAlarmConfiguration::Impl_::Impl_(
    [[maybe_unused]] ::google::protobuf::internal::InternalVisibility visibility,
    ::_pbi::ConstantInitialized) noexcept
      : _cached_size_{0},
        config_hash_(
            &::google::protobuf::internal::fixed_address_empty_string,
            ::_pbi::ConstantInitialized()),
        config_{nullptr} {}

template <typename>
constexpr ProvideAlarmConfiguration::ProvideAlarmConfiguration(::_pbi::ConstantInitialized,
                       const ::_pbi::ClassData* PROTOBUF_NONNULL class_data)
    : ::google::protobuf::Message(
#if defined(PROTOBUF_CUSTOM_VTABLE)
          class_data
#endif  // PROTOBUF_CUSTOM_VTABLE
          ),
      _impl_(internal_visibility(), ::_pbi::ConstantInitialized()) {
}
inline void* PROTOBUF_NONNULL ProvideAlarmConfiguration::PlacementNew_(
    const void* PROTOBUF_NONNULL, void* PROTOBUF_NONNULL mem,
    ::google::protobuf::Arena* PROTOBUF_NULLABLE arena) {
  return ::new (mem) ProvideAlarmConfiguration(arena);
}
constexpr auto ProvideAlarmConfiguration::InternalNewImpl_() {
  return ::google::protobuf::internal::MessageCreator::CopyInit(sizeof(ProvideAlarmConfiguration), alignof(ProvideAlarmConfiguration));
}
constexpr auto ProvideAlarmConfiguration::InternalGenerateClassData_(
    const MessageLite& prototype,
    const ::google::protobuf::internal::TcParseTableBase* tc_table) {
  return ::google::protobuf::internal::ClassDataFull{
      ::google::protobuf::internal::ClassData{
          &prototype,
#ifndef PROTOBUF_MESSAGE_GLOBALS
          &_table_.header,
#else
          tc_table,
#endif
          nullptr,  // IsInitialized
          &ProvideAlarmConfiguration::MergeImpl,
          ::google::protobuf::Message::GetNewImpl<ProvideAlarmConfiguration>(),
#if defined(PROTOBUF_CUSTOM_VTABLE)
          &ProvideAlarmConfiguration::SharedDtor,
          ::google::protobuf::Message::GetClearImpl<ProvideAlarmConfiguration>(), &ProvideAlarmConfiguration::ByteSizeLong,
              &ProvideAlarmConfiguration::_InternalSerialize,
#endif  // PROTOBUF_CUSTOM_VTABLE
          PROTOBUF_FIELD_OFFSET(ProvideAlarmConfiguration, _impl_._cached_size_),
          false,
      },
#ifdef PROTOBUF_MESSAGE_GLOBALS
      &file_reflection_data[1],
#else   // !PROTOBUF_MESSAGE_GLOBALS
      &::_pbi::kDescriptorMethods,
      &descriptor_table_alarm_2fv1_2fconfig_2eproto,
      nullptr,  // tracker
#endif  // PROTOBUF_MESSAGE_GLOBALS
  };
}
struct ProvideAlarmConfigurationGlobalsTypeInternal : ::_pbi::MessageGlobalsBase {
  constexpr ProvideAlarmConfigurationGlobalsTypeInternal()
      :
#ifndef PROTOBUF_MESSAGE_GLOBALS
        _default(::_pbi::ConstantInitialized{},
                 ProvideAlarmConfiguration_class_data_.base())
#else   // !PROTOBUF_MESSAGE_GLOBALS
        MessageGlobalsBase(ProvideAlarmConfiguration::InternalGenerateClassData_(
            _default, &ProvideAlarmConfiguration_globals_._table.header)),
        _default(::_pbi::ConstantInitialized{}, GetClassData()),
        _table(::_pbi::PrivateAccess::GenerateParseTable<ProvideAlarmConfiguration>(
            GetClassData()))
#endif  // PROTOBUF_MESSAGE_GLOBALS
  {
  }
  ~ProvideAlarmConfigurationGlobalsTypeInternal() {}
  union {
    alignas(::_pbi::kMaxMessageAlignment) ProvideAlarmConfiguration _default;
  };
#ifdef PROTOBUF_MESSAGE_GLOBALS
  decltype(::_pbi::PrivateAccess::GenerateParseTable<ProvideAlarmConfiguration>(
      ::std::declval<const ::_pbi::ClassData*>())) _table;
#endif
};
#ifdef PROTOBUF_MESSAGE_GLOBALS
static_assert(PROTOBUF_FIELD_OFFSET(ProvideAlarmConfigurationGlobalsTypeInternal, _default) ==
              ::_pbi::MessageGlobalsBase::OffsetToDefault());
#endif  // PROTOBUF_MESSAGE_GLOBALS

PROTOBUF_ATTRIBUTE_NO_DESTROY PROTOBUF_CONSTINIT
    PROTOBUF_ATTRIBUTE_INIT_PRIORITY1 PROTOBUF_MESSAGE_GLOBALS_CONST ProvideAlarmConfigurationGlobalsTypeInternal ProvideAlarmConfiguration_globals_
        PROTOBUF_MESSAGE_GLOBALS_SECTION(.data.rel.ro);
#if defined(PROTOBUF_CUSTOM_VTABLE)
namespace {
const ::_pbi::ClassData* ProvideAlarmConfiguration_get_class_data() {
#ifdef PROTOBUF_MESSAGE_GLOBALS
  return ProvideAlarmConfiguration_globals_.GetClassData();
#else
  return ProvideAlarmConfiguration_class_data_.base();
#endif  // PROTOBUF_MESSAGE_GLOBALS
}
}  // namespace
#endif  // PROTOBUF_CUSTOM_VTABLE
}  // namespace v1
}  // namespace alarms
static constexpr const ::_pb::EnumDescriptor* PROTOBUF_NONNULL* PROTOBUF_NULLABLE
    file_level_enum_descriptors_alarm_2fv1_2fconfig_2eproto = nullptr;
static constexpr const ::_pb::ServiceDescriptor* PROTOBUF_NONNULL* PROTOBUF_NULLABLE
    file_level_service_descriptors_alarm_2fv1_2fconfig_2eproto = nullptr;
const ::uint32_t
    TableStruct_alarm_2fv1_2fconfig_2eproto::offsets[] ABSL_ATTRIBUTE_SECTION_VARIABLE(
        protodesc_cold) = {
        0x081, // bitmap
        PROTOBUF_FIELD_OFFSET(::alarms::v1::SendAlarmConfiguration, _impl_._has_bits_),
        4, // hasbit index offset
        PROTOBUF_FIELD_OFFSET(::alarms::v1::SendAlarmConfiguration, _impl_.config_hash_),
        0,
        0x081, // bitmap
        PROTOBUF_FIELD_OFFSET(::alarms::v1::ProvideAlarmConfiguration, _impl_._has_bits_),
        5, // hasbit index offset
        PROTOBUF_FIELD_OFFSET(::alarms::v1::ProvideAlarmConfiguration, _impl_.config_hash_),
        PROTOBUF_FIELD_OFFSET(::alarms::v1::ProvideAlarmConfiguration, _impl_.config_),
        0,
        1,
        0x081, // bitmap
        PROTOBUF_FIELD_OFFSET(::alarms::v1::AlarmConfiguration, _impl_._has_bits_),
        38, // hasbit index offset
        PROTOBUF_FIELD_OFFSET(::alarms::v1::AlarmConfiguration, _impl_.alarm_),
        PROTOBUF_FIELD_OFFSET(::alarms::v1::AlarmConfiguration, _impl_.template__),
        PROTOBUF_FIELD_OFFSET(::alarms::v1::AlarmConfiguration, _impl_.on_chart_),
        PROTOBUF_FIELD_OFFSET(::alarms::v1::AlarmConfiguration, _impl_.classification_),
        PROTOBUF_FIELD_OFFSET(::alarms::v1::AlarmConfiguration, _impl_.type_),
        PROTOBUF_FIELD_OFFSET(::alarms::v1::AlarmConfiguration, _impl_.component_),
        PROTOBUF_FIELD_OFFSET(::alarms::v1::AlarmConfiguration, _impl_.os_),
        PROTOBUF_FIELD_OFFSET(::alarms::v1::AlarmConfiguration, _impl_.hosts_),
        PROTOBUF_FIELD_OFFSET(::alarms::v1::AlarmConfiguration, _impl_.plugin_),
        PROTOBUF_FIELD_OFFSET(::alarms::v1::AlarmConfiguration, _impl_.module_),
        PROTOBUF_FIELD_OFFSET(::alarms::v1::AlarmConfiguration, _impl_.charts_),
        PROTOBUF_FIELD_OFFSET(::alarms::v1::AlarmConfiguration, _impl_.families_),
        PROTOBUF_FIELD_OFFSET(::alarms::v1::AlarmConfiguration, _impl_.lookup_),
        PROTOBUF_FIELD_OFFSET(::alarms::v1::AlarmConfiguration, _impl_.every_),
        PROTOBUF_FIELD_OFFSET(::alarms::v1::AlarmConfiguration, _impl_.units_),
        PROTOBUF_FIELD_OFFSET(::alarms::v1::AlarmConfiguration, _impl_.green_),
        PROTOBUF_FIELD_OFFSET(::alarms::v1::AlarmConfiguration, _impl_.red_),
        PROTOBUF_FIELD_OFFSET(::alarms::v1::AlarmConfiguration, _impl_.calculation_expr_),
        PROTOBUF_FIELD_OFFSET(::alarms::v1::AlarmConfiguration, _impl_.warning_expr_),
        PROTOBUF_FIELD_OFFSET(::alarms::v1::AlarmConfiguration, _impl_.critical_expr_),
        PROTOBUF_FIELD_OFFSET(::alarms::v1::AlarmConfiguration, _impl_.recipient_),
        PROTOBUF_FIELD_OFFSET(::alarms::v1::AlarmConfiguration, _impl_.exec_),
        PROTOBUF_FIELD_OFFSET(::alarms::v1::AlarmConfiguration, _impl_.delay_),
        PROTOBUF_FIELD_OFFSET(::alarms::v1::AlarmConfiguration, _impl_.repeat_),
        PROTOBUF_FIELD_OFFSET(::alarms::v1::AlarmConfiguration, _impl_.info_),
        PROTOBUF_FIELD_OFFSET(::alarms::v1::AlarmConfiguration, _impl_.options_),
        PROTOBUF_FIELD_OFFSET(::alarms::v1::AlarmConfiguration, _impl_.host_labels_),
        PROTOBUF_FIELD_OFFSET(::alarms::v1::AlarmConfiguration, _impl_.p_db_lookup_after_),
        PROTOBUF_FIELD_OFFSET(::alarms::v1::AlarmConfiguration, _impl_.p_db_lookup_before_),
        PROTOBUF_FIELD_OFFSET(::alarms::v1::AlarmConfiguration, _impl_.p_db_lookup_dimensions_),
        PROTOBUF_FIELD_OFFSET(::alarms::v1::AlarmConfiguration, _impl_.p_db_lookup_method_),
        PROTOBUF_FIELD_OFFSET(::alarms::v1::AlarmConfiguration, _impl_.p_db_lookup_options_),
        PROTOBUF_FIELD_OFFSET(::alarms::v1::AlarmConfiguration, _impl_.p_update_every_),
        PROTOBUF_FIELD_OFFSET(::alarms::v1::AlarmConfiguration, _impl_.chart_labels_),
        PROTOBUF_FIELD_OFFSET(::alarms::v1::AlarmConfiguration, _impl_.summary_),
        0,
        1,
        2,
        3,
        4,
        5,
        6,
        7,
        8,
        9,
        10,
        11,
        12,
        13,
        14,
        15,
        16,
        17,
        18,
        19,
        20,
        21,
        22,
        23,
        24,
        25,
        26,
        29,
        30,
        27,
        28,
        31,
        34,
        32,
        33,
};

static const ::_pbi::MigrationSchema
    schemas[] ABSL_ATTRIBUTE_SECTION_VARIABLE(protodesc_cold) = {
        {0, sizeof(::alarms::v1::SendAlarmConfiguration)},
        {5, sizeof(::alarms::v1::ProvideAlarmConfiguration)},
        {12, sizeof(::alarms::v1::AlarmConfiguration)},
};
static const ::_pbi::MessageGlobalsBase* PROTOBUF_NONNULL const
    file_message_globals[] = {
        &::alarms::v1::SendAlarmConfiguration_globals_,
        &::alarms::v1::ProvideAlarmConfiguration_globals_,
        &::alarms::v1::AlarmConfiguration_globals_,
};
const char descriptor_table_protodef_alarm_2fv1_2fconfig_2eproto[] ABSL_ATTRIBUTE_SECTION_VARIABLE(
    protodesc_cold) = {
    "\n\025alarm/v1/config.proto\022\talarms.v1\"-\n\026Se"
    "ndAlarmConfiguration\022\023\n\013config_hash\030\001 \001("
    "\t\"_\n\031ProvideAlarmConfiguration\022\023\n\013config"
    "_hash\030\001 \001(\t\022-\n\006config\030\002 \001(\0132\035.alarms.v1."
    "AlarmConfiguration\"\265\005\n\022AlarmConfiguratio"
    "n\022\r\n\005alarm\030\001 \001(\t\022\020\n\010template\030\002 \001(\t\022\020\n\010on"
    "_chart\030\003 \001(\t\022\026\n\016classification\030\004 \001(\t\022\014\n\004"
    "type\030\005 \001(\t\022\021\n\tcomponent\030\006 \001(\t\022\n\n\002os\030\007 \001("
    "\t\022\r\n\005hosts\030\010 \001(\t\022\016\n\006plugin\030\t \001(\t\022\016\n\006modu"
    "le\030\n \001(\t\022\016\n\006charts\030\013 \001(\t\022\024\n\010families\030\014 \001"
    "(\tB\002\030\001\022\016\n\006lookup\030\r \001(\t\022\r\n\005every\030\016 \001(\t\022\r\n"
    "\005units\030\017 \001(\t\022\r\n\005green\030\020 \001(\t\022\013\n\003red\030\021 \001(\t"
    "\022\030\n\020calculation_expr\030\022 \001(\t\022\024\n\014warning_ex"
    "pr\030\023 \001(\t\022\025\n\rcritical_expr\030\024 \001(\t\022\021\n\trecip"
    "ient\030\025 \001(\t\022\014\n\004exec\030\026 \001(\t\022\r\n\005delay\030\027 \001(\t\022"
    "\016\n\006repeat\030\030 \001(\t\022\014\n\004info\030\031 \001(\t\022\017\n\007options"
    "\030\032 \001(\t\022\023\n\013host_labels\030\033 \001(\t\022\031\n\021p_db_look"
    "up_after\030\034 \001(\005\022\032\n\022p_db_lookup_before\030\035 \001"
    "(\005\022\036\n\026p_db_lookup_dimensions\030\036 \001(\t\022\032\n\022p_"
    "db_lookup_method\030\037 \001(\t\022\033\n\023p_db_lookup_op"
    "tions\030  \001(\t\022\026\n\016p_update_every\030! \001(\005\022\024\n\014c"
    "hart_labels\030\" \001(\t\022\017\n\007summary\030# \001(\tB\022Z\020al"
    "arms/v1;alarmsb\006proto3"
};
static ::absl::once_flag descriptor_table_alarm_2fv1_2fconfig_2eproto_once;
PROTOBUF_CONSTINIT const ::_pbi::DescriptorTable descriptor_table_alarm_2fv1_2fconfig_2eproto = {
    false,
    false,
    902,
    descriptor_table_protodef_alarm_2fv1_2fconfig_2eproto,
    "alarm/v1/config.proto",
    &descriptor_table_alarm_2fv1_2fconfig_2eproto_once,
    nullptr,
    0,
    3,
    schemas,
    file_message_globals,
    TableStruct_alarm_2fv1_2fconfig_2eproto::offsets,
    file_level_enum_descriptors_alarm_2fv1_2fconfig_2eproto,
    file_level_service_descriptors_alarm_2fv1_2fconfig_2eproto,
};
namespace alarms {
namespace v1 {
// ===================================================================

SendAlarmConfiguration::SendAlarmConfiguration(::google::protobuf::Arena* PROTOBUF_NULLABLE arena)
#if defined(PROTOBUF_CUSTOM_VTABLE)
    : ::google::protobuf::Message(arena, SendAlarmConfiguration_get_class_data()) {
#else   // PROTOBUF_CUSTOM_VTABLE
    : ::google::protobuf::Message(arena) {
#endif  // PROTOBUF_CUSTOM_VTABLE
  SharedCtor(arena);
  // @@protoc_insertion_point(arena_constructor:alarms.v1.SendAlarmConfiguration)
}
PROTOBUF_NDEBUG_INLINE SendAlarmConfiguration::Impl_::Impl_(
    [[maybe_unused]] ::google::protobuf::internal::InternalVisibility visibility,
    [[maybe_unused]] ::google::protobuf::Arena* PROTOBUF_NULLABLE arena, const Impl_& from,
    [[maybe_unused]] const ::alarms::v1::SendAlarmConfiguration& from_msg)
      : _has_bits_{from._has_bits_},
        _cached_size_{0},
        config_hash_(arena, from.config_hash_) {}

SendAlarmConfiguration::SendAlarmConfiguration(
    ::google::protobuf::Arena* PROTOBUF_NULLABLE arena,
    const SendAlarmConfiguration& from)
#if defined(PROTOBUF_CUSTOM_VTABLE)
    : ::google::protobuf::Message(arena, SendAlarmConfiguration_get_class_data()) {

#else   // PROTOBUF_CUSTOM_VTABLE
    : ::google::protobuf::Message(arena) {
#endif  // PROTOBUF_CUSTOM_VTABLE
  SendAlarmConfiguration* const _this = this;
  (void)_this;
  _internal_metadata_.MergeFrom<::google::protobuf::UnknownFieldSet>(
      from._internal_metadata_);
  new (&_impl_) Impl_(internal_visibility(), arena, from._impl_, from);

  // @@protoc_insertion_point(copy_constructor:alarms.v1.SendAlarmConfiguration)
}
PROTOBUF_NDEBUG_INLINE SendAlarmConfiguration::Impl_::Impl_(
    [[maybe_unused]] ::google::protobuf::internal::InternalVisibility visibility,
    [[maybe_unused]] ::google::protobuf::Arena* PROTOBUF_NULLABLE arena)
      : _cached_size_{0},
        config_hash_(arena) {}

inline void SendAlarmConfiguration::SharedCtor(::_pb::Arena* PROTOBUF_NULLABLE arena) {
  new (&_impl_) Impl_(internal_visibility(), arena);
}
SendAlarmConfiguration::~SendAlarmConfiguration() {
  // @@protoc_insertion_point(destructor:alarms.v1.SendAlarmConfiguration)
  SharedDtor(*this);
}
inline void SendAlarmConfiguration::SharedDtor(MessageLite& self) {
  SendAlarmConfiguration& this_ = static_cast<SendAlarmConfiguration&>(self);
  if constexpr (::_pbi::DebugHardenCheckHasBitConsistency()) {
    this_.CheckHasBitConsistency();
  }
  this_._internal_metadata_.Delete<::google::protobuf::UnknownFieldSet>();
  ABSL_DCHECK(this_.GetArena() == nullptr);
  this_._impl_.config_hash_.Destroy();
  this_._impl_.~Impl_();
}

#ifndef PROTOBUF_MESSAGE_GLOBALS
PROTOBUF_CONSTINIT PROTOBUF_ATTRIBUTE_INIT_PRIORITY1 const
    ::google::protobuf::internal::ClassDataFull SendAlarmConfiguration_class_data_ =
        SendAlarmConfiguration::InternalGenerateClassData_(SendAlarmConfiguration_globals_._default);

PROTOBUF_ATTRIBUTE_WEAK const ::google::protobuf::internal::ClassData* PROTOBUF_NONNULL
SendAlarmConfiguration::GetClassData() const {
  ::google::protobuf::internal::PrefetchToLocalCache(&SendAlarmConfiguration_class_data_);
  ::google::protobuf::internal::PrefetchToLocalCache(SendAlarmConfiguration_class_data_.tc_table);
  return SendAlarmConfiguration_class_data_.base();
}
#else
PROTOBUF_ATTRIBUTE_WEAK const ::google::protobuf::internal::ClassData* PROTOBUF_NONNULL
SendAlarmConfiguration::GetClassData() const {
  ::google::protobuf::internal::PrefetchToLocalCache(&SendAlarmConfiguration_globals_);
  ::google::protobuf::internal::PrefetchToLocalCache(
      ::google::protobuf::internal::MessageGlobalsBase::ToParseTableBase(&SendAlarmConfiguration_globals_));
  return SendAlarmConfiguration_globals_.GetClassData();
}
#endif  // !PROTOBUF_MESSAGE_GLOBALS
#ifndef PROTOBUF_MESSAGE_GLOBALS
PROTOBUF_CONSTINIT
PROTOBUF_ATTRIBUTE_INIT_PRIORITY1 const SendAlarmConfiguration::ParseTableT_
    SendAlarmConfiguration::_table_ =
        SendAlarmConfiguration::InternalGenerateParseTable_(SendAlarmConfiguration_class_data_.base());
#endif  // !PROTOBUF_MESSAGE_GLOBALS
PROTOBUF_NOINLINE void SendAlarmConfiguration::Clear() {
// @@protoc_insertion_point(message_clear_start:alarms.v1.SendAlarmConfiguration)
  ::google::protobuf::internal::TSanWrite(&_impl_);
  ::uint32_t cached_has_bits = 0;
  // Prevent compiler warnings about cached_has_bits being unused
  (void) cached_has_bits;

  cached_has_bits = _impl_._has_bits_[0];
  if (CheckHasBit(cached_has_bits, 0x00000001U)) {
    _impl_.config_hash_.ClearNonDefaultToEmpty();
  }
  _impl_._has_bits_.Clear();
  _internal_metadata_.Clear<::google::protobuf::UnknownFieldSet>();
}

#if defined(PROTOBUF_CUSTOM_VTABLE)
::uint8_t* PROTOBUF_NONNULL SendAlarmConfiguration::_InternalSerialize(
    const ::google::protobuf::MessageLite& base, ::uint8_t* PROTOBUF_NONNULL target,
    ::google::protobuf::io::EpsCopyOutputStream* PROTOBUF_NONNULL stream) {
  const SendAlarmConfiguration& this_ = static_cast<const SendAlarmConfiguration&>(base);
#else   // PROTOBUF_CUSTOM_VTABLE
::uint8_t* PROTOBUF_NONNULL SendAlarmConfiguration::_InternalSerialize(
    ::uint8_t* PROTOBUF_NONNULL target,
    ::google::protobuf::io::EpsCopyOutputStream* PROTOBUF_NONNULL stream) const {
  const SendAlarmConfiguration& this_ = *this;
#endif  // PROTOBUF_CUSTOM_VTABLE
  if constexpr (::_pbi::DebugHardenCheckHasBitConsistency()) {
    this_.CheckHasBitConsistency();
  }
  // @@protoc_insertion_point(serialize_to_array_start:alarms.v1.SendAlarmConfiguration)
  ::uint32_t cached_has_bits = 0;
  (void)cached_has_bits;

  cached_has_bits = this_._impl_._has_bits_[0];
  // string config_hash = 1;
  if (CheckHasBit(cached_has_bits, 0x00000001U)) {
    if (!this_._internal_config_hash().empty()) {
      const ::std::string& _s = this_._internal_config_hash();
      ::google::protobuf::internal::WireFormatLite::VerifyUtf8String(
          _s.data(), static_cast<int>(_s.length()), ::google::protobuf::internal::WireFormatLite::SERIALIZE, "alarms.v1.SendAlarmConfiguration.config_hash");
      target = stream->WriteStringMaybeAliased(1, _s, target);
    }
  }

  if (ABSL_PREDICT_FALSE(this_._internal_metadata_.have_unknown_fields())) {
    target =
        ::_pbi::WireFormat::InternalSerializeUnknownFieldsToArray(
            this_._internal_metadata_.unknown_fields<::google::protobuf::UnknownFieldSet>(::google::protobuf::UnknownFieldSet::default_instance), target, stream);
  }
  // @@protoc_insertion_point(serialize_to_array_end:alarms.v1.SendAlarmConfiguration)
  return target;
}

#if defined(PROTOBUF_CUSTOM_VTABLE)
::size_t SendAlarmConfiguration::ByteSizeLong(const MessageLite& base) {
  const SendAlarmConfiguration& this_ = static_cast<const SendAlarmConfiguration&>(base);
#else   // PROTOBUF_CUSTOM_VTABLE
::size_t SendAlarmConfiguration::ByteSizeLong() const {
  const SendAlarmConfiguration& this_ = *this;
#endif  // PROTOBUF_CUSTOM_VTABLE
  // @@protoc_insertion_point(message_byte_size_start:alarms.v1.SendAlarmConfiguration)
  ::size_t total_size = 0;

  ::uint32_t cached_has_bits = 0;
  // Prevent compiler warnings about cached_has_bits being unused
  (void)cached_has_bits;

   {
    // string config_hash = 1;
    cached_has_bits = this_._impl_._has_bits_[0];
    if (CheckHasBit(cached_has_bits, 0x00000001U)) {
      if (!this_._internal_config_hash().empty()) {
        total_size += 1 + ::google::protobuf::internal::WireFormatLite::StringSize(
                                        this_._internal_config_hash());
      }
    }
  }
  return this_.MaybeComputeUnknownFieldsSize(total_size,
                                             &this_._impl_._cached_size_);
}

void SendAlarmConfiguration::MergeImpl(::google::protobuf::MessageLite& to_msg,
                      const ::google::protobuf::MessageLite& from_msg) {
   auto* const _this = static_cast<SendAlarmConfiguration*>(&to_msg);
  auto& from = static_cast<const SendAlarmConfiguration&>(from_msg);
  if constexpr (::_pbi::DebugHardenCheckHasBitConsistency()) {
    from.CheckHasBitConsistency();
  }
  // @@protoc_insertion_point(class_specific_merge_from_start:alarms.v1.SendAlarmConfiguration)
  ABSL_DCHECK_NE(&from, _this);
  ::uint32_t cached_has_bits = 0;
  (void)cached_has_bits;

  cached_has_bits = from._impl_._has_bits_[0];
  if (CheckHasBit(cached_has_bits, 0x00000001U)) {
    if (!from._internal_config_hash().empty()) {
      _this->_internal_set_config_hash(from._internal_config_hash());
    } else {
      if (_this->_impl_.config_hash_.IsDefault()) {
        _this->_internal_set_config_hash("");
      }
    }
  }
  _this->_impl_._has_bits_[0] |= cached_has_bits;
  _this->_internal_metadata_.MergeFrom<::google::protobuf::UnknownFieldSet>(
      from._internal_metadata_);
}

void SendAlarmConfiguration::CopyFrom(const SendAlarmConfiguration& from) {
  // @@protoc_insertion_point(class_specific_copy_from_start:alarms.v1.SendAlarmConfiguration)
  if (&from == this) return;
  Clear();
  MergeFrom(from);
}


void SendAlarmConfiguration::InternalSwap(SendAlarmConfiguration* PROTOBUF_RESTRICT PROTOBUF_NONNULL other) {
  using ::std::swap;
  auto* arena = GetArena();
  ABSL_DCHECK_EQ(arena, other->GetArena());
  _internal_metadata_.InternalSwap(&other->_internal_metadata_);
  swap(_impl_._has_bits_[0], other->_impl_._has_bits_[0]);
  ::_pbi::ArenaStringPtr::InternalSwap(&_impl_.config_hash_, &other->_impl_.config_hash_, arena);
}

::google::protobuf::Metadata SendAlarmConfiguration::GetMetadata() const {
  return ::google::protobuf::Message::GetMetadataImpl(GetClassData()->full());
}
// ===================================================================

ProvideAlarmConfiguration::ProvideAlarmConfiguration(::google::protobuf::Arena* PROTOBUF_NULLABLE arena)
#if defined(PROTOBUF_CUSTOM_VTABLE)
    : ::google::protobuf::Message(arena, ProvideAlarmConfiguration_get_class_data()) {
#else   // PROTOBUF_CUSTOM_VTABLE
    : ::google::protobuf::Message(arena) {
#endif  // PROTOBUF_CUSTOM_VTABLE
  SharedCtor(arena);
  // @@protoc_insertion_point(arena_constructor:alarms.v1.ProvideAlarmConfiguration)
}
PROTOBUF_NDEBUG_INLINE ProvideAlarmConfiguration::Impl_::Impl_(
    [[maybe_unused]] ::google::protobuf::internal::InternalVisibility visibility,
    [[maybe_unused]] ::google::protobuf::Arena* PROTOBUF_NULLABLE arena, const Impl_& from,
    [[maybe_unused]] const ::alarms::v1::ProvideAlarmConfiguration& from_msg)
      : _has_bits_{from._has_bits_},
        _cached_size_{0},
        config_hash_(arena, from.config_hash_) {}

ProvideAlarmConfiguration::ProvideAlarmConfiguration(
    ::google::protobuf::Arena* PROTOBUF_NULLABLE arena,
    const ProvideAlarmConfiguration& from)
#if defined(PROTOBUF_CUSTOM_VTABLE)
    : ::google::protobuf::Message(arena, ProvideAlarmConfiguration_get_class_data()) {

#else   // PROTOBUF_CUSTOM_VTABLE
    : ::google::protobuf::Message(arena) {
#endif  // PROTOBUF_CUSTOM_VTABLE
  ProvideAlarmConfiguration* const _this = this;
  (void)_this;
  _internal_metadata_.MergeFrom<::google::protobuf::UnknownFieldSet>(
      from._internal_metadata_);
  new (&_impl_) Impl_(internal_visibility(), arena, from._impl_, from);
  ::uint32_t cached_has_bits = _impl_._has_bits_[0];
  _impl_.config_ = (CheckHasBit(cached_has_bits, 0x00000002U))
                ? ::google::protobuf::Message::CopyConstruct(arena, *from._impl_.config_)
                : nullptr;

  // @@protoc_insertion_point(copy_constructor:alarms.v1.ProvideAlarmConfiguration)
}
PROTOBUF_NDEBUG_INLINE ProvideAlarmConfiguration::Impl_::Impl_(
    [[maybe_unused]] ::google::protobuf::internal::InternalVisibility visibility,
    [[maybe_unused]] ::google::protobuf::Arena* PROTOBUF_NULLABLE arena)
      : _cached_size_{0},
        config_hash_(arena) {}

inline void ProvideAlarmConfiguration::SharedCtor(::_pb::Arena* PROTOBUF_NULLABLE arena) {
  new (&_impl_) Impl_(internal_visibility(), arena);
  _impl_.config_ = {};
}
ProvideAlarmConfiguration::~ProvideAlarmConfiguration() {
  // @@protoc_insertion_point(destructor:alarms.v1.ProvideAlarmConfiguration)
  SharedDtor(*this);
}
inline void ProvideAlarmConfiguration::SharedDtor(MessageLite& self) {
  ProvideAlarmConfiguration& this_ = static_cast<ProvideAlarmConfiguration&>(self);
  if constexpr (::_pbi::DebugHardenCheckHasBitConsistency()) {
    this_.CheckHasBitConsistency();
  }
  this_._internal_metadata_.Delete<::google::protobuf::UnknownFieldSet>();
  ABSL_DCHECK(this_.GetArena() == nullptr);
  this_._impl_.config_hash_.Destroy();
  delete this_._impl_.config_;
  this_._impl_.~Impl_();
}

#ifndef PROTOBUF_MESSAGE_GLOBALS
PROTOBUF_CONSTINIT PROTOBUF_ATTRIBUTE_INIT_PRIORITY1 const
    ::google::protobuf::internal::ClassDataFull ProvideAlarmConfiguration_class_data_ =
        ProvideAlarmConfiguration::InternalGenerateClassData_(ProvideAlarmConfiguration_globals_._default);

PROTOBUF_ATTRIBUTE_WEAK const ::google::protobuf::internal::ClassData* PROTOBUF_NONNULL
ProvideAlarmConfiguration::GetClassData() const {
  ::google::protobuf::internal::PrefetchToLocalCache(&ProvideAlarmConfiguration_class_data_);
  ::google::protobuf::internal::PrefetchToLocalCache(ProvideAlarmConfiguration_class_data_.tc_table);
  return ProvideAlarmConfiguration_class_data_.base();
}
#else
PROTOBUF_ATTRIBUTE_WEAK const ::google::protobuf::internal::ClassData* PROTOBUF_NONNULL
ProvideAlarmConfiguration::GetClassData() const {
  ::google::protobuf::internal::PrefetchToLocalCache(&ProvideAlarmConfiguration_globals_);
  ::google::protobuf::internal::PrefetchToLocalCache(
      ::google::protobuf::internal::MessageGlobalsBase::ToParseTableBase(&ProvideAlarmConfiguration_globals_));
  return ProvideAlarmConfiguration_globals_.GetClassData();
}
#endif  // !PROTOBUF_MESSAGE_GLOBALS
#ifndef PROTOBUF_MESSAGE_GLOBALS
PROTOBUF_CONSTINIT
PROTOBUF_ATTRIBUTE_INIT_PRIORITY1 const ProvideAlarmConfiguration::ParseTableT_
    ProvideAlarmConfiguration::_table_ =
        ProvideAlarmConfiguration::InternalGenerateParseTable_(ProvideAlarmConfiguration_class_data_.base());
#endif  // !PROTOBUF_MESSAGE_GLOBALS
PROTOBUF_NOINLINE void ProvideAlarmConfiguration::Clear() {
// @@protoc_insertion_point(message_clear_start:alarms.v1.ProvideAlarmConfiguration)
  ::google::protobuf::internal::TSanWrite(&_impl_);
  ::uint32_t cached_has_bits = 0;
  // Prevent compiler warnings about cached_has_bits being unused
  (void) cached_has_bits;

  cached_has_bits = _impl_._has_bits_[0];
  if (BatchCheckHasBit(cached_has_bits, 0x00000003U)) {
    if (CheckHasBit(cached_has_bits, 0x00000001U)) {
      _impl_.config_hash_.ClearNonDefaultToEmpty();
    }
    if (CheckHasBit(cached_has_bits, 0x00000002U)) {
      ABSL_DCHECK(_impl_.config_ != nullptr);
      _impl_.config_->Clear();
    }
  }
  _impl_._has_bits_.Clear();
  _internal_metadata_.Clear<::google::protobuf::UnknownFieldSet>();
}

#if defined(PROTOBUF_CUSTOM_VTABLE)
::uint8_t* PROTOBUF_NONNULL ProvideAlarmConfiguration::_InternalSerialize(
    const ::google::protobuf::MessageLite& base, ::uint8_t* PROTOBUF_NONNULL target,
    ::google::protobuf::io::EpsCopyOutputStream* PROTOBUF_NONNULL stream) {
  const ProvideAlarmConfiguration& this_ = static_cast<const ProvideAlarmConfiguration&>(base);
#else   // PROTOBUF_CUSTOM_VTABLE
::uint8_t* PROTOBUF_NONNULL ProvideAlarmConfiguration::_InternalSerialize(
    ::uint8_t* PROTOBUF_NONNULL target,
    ::google::protobuf::io::EpsCopyOutputStream* PROTOBUF_NONNULL stream) const {
  const ProvideAlarmConfiguration& this_ = *this;
#endif  // PROTOBUF_CUSTOM_VTABLE
  if constexpr (::_pbi::DebugHardenCheckHasBitConsistency()) {
    this_.CheckHasBitConsistency();
  }
  // @@protoc_insertion_point(serialize_to_array_start:alarms.v1.ProvideAlarmConfiguration)
  ::uint32_t cached_has_bits = 0;
  (void)cached_has_bits;

  cached_has_bits = this_._impl_._has_bits_[0];
  // string config_hash = 1;
  if (CheckHasBit(cached_has_bits, 0x00000001U)) {
    if (!this_._internal_config_hash().empty()) {
      const ::std::string& _s = this_._internal_config_hash();
      ::google::protobuf::internal::WireFormatLite::VerifyUtf8String(
          _s.data(), static_cast<int>(_s.length()), ::google::protobuf::internal::WireFormatLite::SERIALIZE, "alarms.v1.ProvideAlarmConfiguration.config_hash");
      target = stream->WriteStringMaybeAliased(1, _s, target);
    }
  }

  // .alarms.v1.AlarmConfiguration config = 2;
  if (CheckHasBit(cached_has_bits, 0x00000002U)) {
    target = ::google::protobuf::internal::WireFormatLite::InternalWriteMessage(
        2, *this_._impl_.config_, this_._impl_.config_->GetCachedSize(), target,
        stream);
  }

  if (ABSL_PREDICT_FALSE(this_._internal_metadata_.have_unknown_fields())) {
    target =
        ::_pbi::WireFormat::InternalSerializeUnknownFieldsToArray(
            this_._internal_metadata_.unknown_fields<::google::protobuf::UnknownFieldSet>(::google::protobuf::UnknownFieldSet::default_instance), target, stream);
  }
  // @@protoc_insertion_point(serialize_to_array_end:alarms.v1.ProvideAlarmConfiguration)
  return target;
}

#if defined(PROTOBUF_CUSTOM_VTABLE)
::size_t ProvideAlarmConfiguration::ByteSizeLong(const MessageLite& base) {
  const ProvideAlarmConfiguration& this_ = static_cast<const ProvideAlarmConfiguration&>(base);
#else   // PROTOBUF_CUSTOM_VTABLE
::size_t ProvideAlarmConfiguration::ByteSizeLong() const {
  const ProvideAlarmConfiguration& this_ = *this;
#endif  // PROTOBUF_CUSTOM_VTABLE
  // @@protoc_insertion_point(message_byte_size_start:alarms.v1.ProvideAlarmConfiguration)
  ::size_t total_size = 0;

  ::uint32_t cached_has_bits = 0;
  // Prevent compiler warnings about cached_has_bits being unused
  (void)cached_has_bits;

  ::_pbi::Prefetch5LinesFrom7Lines(&this_);
  cached_has_bits = this_._impl_._has_bits_[0];
  if (BatchCheckHasBit(cached_has_bits, 0x00000003U)) {
    // string config_hash = 1;
    if (CheckHasBit(cached_has_bits, 0x00000001U)) {
      if (!this_._internal_config_hash().empty()) {
        total_size += 1 + ::google::protobuf::internal::WireFormatLite::StringSize(
                                        this_._internal_config_hash());
      }
    }
    // .alarms.v1.AlarmConfiguration config = 2;
    if (CheckHasBit(cached_has_bits, 0x00000002U)) {
      total_size += 1 +
                    ::google::protobuf::internal::WireFormatLite::MessageSize(*this_._impl_.config_);
    }
  }
  return this_.MaybeComputeUnknownFieldsSize(total_size,
                                             &this_._impl_._cached_size_);
}

void ProvideAlarmConfiguration::MergeImpl(::google::protobuf::MessageLite& to_msg,
                      const ::google::protobuf::MessageLite& from_msg) {
   auto* const _this = static_cast<ProvideAlarmConfiguration*>(&to_msg);
  auto& from = static_cast<const ProvideAlarmConfiguration&>(from_msg);
  if constexpr (::_pbi::DebugHardenCheckHasBitConsistency()) {
    from.CheckHasBitConsistency();
  }
  ::google::protobuf::Arena* arena = _this->GetArena();
  // @@protoc_insertion_point(class_specific_merge_from_start:alarms.v1.ProvideAlarmConfiguration)
  ABSL_DCHECK_NE(&from, _this);
  ::uint32_t cached_has_bits = 0;
  (void)cached_has_bits;

  cached_has_bits = from._impl_._has_bits_[0];
  if (BatchCheckHasBit(cached_has_bits, 0x00000003U)) {
    if (CheckHasBit(cached_has_bits, 0x00000001U)) {
      if (!from._internal_config_hash().empty()) {
        _this->_internal_set_config_hash(from._internal_config_hash());
      } else {
        if (_this->_impl_.config_hash_.IsDefault()) {
          _this->_internal_set_config_hash("");
        }
      }
    }
    if (CheckHasBit(cached_has_bits, 0x00000002U)) {
      ABSL_DCHECK(from._impl_.config_ != nullptr);
      if (_this->_impl_.config_ == nullptr) {
        _this->_impl_.config_ = ::google::protobuf::Message::CopyConstruct(arena, *from._impl_.config_);
      } else {
        _this->_impl_.config_->MergeFrom(*from._impl_.config_);
      }
    }
  }
  _this->_impl_._has_bits_[0] |= cached_has_bits;
  _this->_internal_metadata_.MergeFrom<::google::protobuf::UnknownFieldSet>(
      from._internal_metadata_);
}

void ProvideAlarmConfiguration::CopyFrom(const ProvideAlarmConfiguration& from) {
  // @@protoc_insertion_point(class_specific_copy_from_start:alarms.v1.ProvideAlarmConfiguration)
  if (&from == this) return;
  Clear();
  MergeFrom(from);
}


void ProvideAlarmConfiguration::InternalSwap(ProvideAlarmConfiguration* PROTOBUF_RESTRICT PROTOBUF_NONNULL other) {
  using ::std::swap;
  auto* arena = GetArena();
  ABSL_DCHECK_EQ(arena, other->GetArena());
  _internal_metadata_.InternalSwap(&other->_internal_metadata_);
  swap(_impl_._has_bits_[0], other->_impl_._has_bits_[0]);
  ::_pbi::ArenaStringPtr::InternalSwap(&_impl_.config_hash_, &other->_impl_.config_hash_, arena);
  swap(_impl_.config_, other->_impl_.config_);
}

::google::protobuf::Metadata ProvideAlarmConfiguration::GetMetadata() const {
  return ::google::protobuf::Message::GetMetadataImpl(GetClassData()->full());
}
// ===================================================================

AlarmConfiguration::AlarmConfiguration(::google::protobuf::Arena* PROTOBUF_NULLABLE arena)
#if defined(PROTOBUF_CUSTOM_VTABLE)
    : ::google::protobuf::Message(arena, AlarmConfiguration_get_class_data()) {
#else   // PROTOBUF_CUSTOM_VTABLE
    : ::google::protobuf::Message(arena) {
#endif  // PROTOBUF_CUSTOM_VTABLE
  SharedCtor(arena);
  // @@protoc_insertion_point(arena_constructor:alarms.v1.AlarmConfiguration)
}
PROTOBUF_NDEBUG_INLINE AlarmConfiguration::Impl_::Impl_(
    [[maybe_unused]] ::google::protobuf::internal::InternalVisibility visibility,
    [[maybe_unused]] ::google::protobuf::Arena* PROTOBUF_NULLABLE arena, const Impl_& from,
    [[maybe_unused]] const ::alarms::v1::AlarmConfiguration& from_msg)
      : _has_bits_{from._has_bits_},
        _cached_size_{0},
        alarm_(arena, from.alarm_),
        template__(arena, from.template__),
        on_chart_(arena, from.on_chart_),
        classification_(arena, from.classification_),
        type_(arena, from.type_),
        component_(arena, from.component_),
        os_(arena, from.os_),
        hosts_(arena, from.hosts_),
        plugin_(arena, from.plugin_),
        module_(arena, from.module_),
        charts_(arena, from.charts_),
        families_(arena, from.families_),
        lookup_(arena, from.lookup_),
        every_(arena, from.every_),
        units_(arena, from.units_),
        green_(arena, from.green_),
        red_(arena, from.red_),
        calculation_expr_(arena, from.calculation_expr_),
        warning_expr_(arena, from.warning_expr_),
        critical_expr_(arena, from.critical_expr_),
        recipient_(arena, from.recipient_),
        exec_(arena, from.exec_),
        delay_(arena, from.delay_),
        repeat_(arena, from.repeat_),
        info_(arena, from.info_),
        options_(arena, from.options_),
        host_labels_(arena, from.host_labels_),
        p_db_lookup_dimensions_(arena, from.p_db_lookup_dimensions_),
        p_db_lookup_method_(arena, from.p_db_lookup_method_),
        p_db_lookup_options_(arena, from.p_db_lookup_options_),
        chart_labels_(arena, from.chart_labels_),
        summary_(arena, from.summary_) {}

AlarmConfiguration::AlarmConfiguration(
    ::google::protobuf::Arena* PROTOBUF_NULLABLE arena,
    const AlarmConfiguration& from)
#if defined(PROTOBUF_CUSTOM_VTABLE)
    : ::google::protobuf::Message(arena, AlarmConfiguration_get_class_data()) {

#else   // PROTOBUF_CUSTOM_VTABLE
    : ::google::protobuf::Message(arena) {
#endif  // PROTOBUF_CUSTOM_VTABLE
  AlarmConfiguration* const _this = this;
  (void)_this;
  _internal_metadata_.MergeFrom<::google::protobuf::UnknownFieldSet>(
      from._internal_metadata_);
  new (&_impl_) Impl_(internal_visibility(), arena, from._impl_, from);
  ::memcpy(reinterpret_cast<char*>(&_impl_) +
               offsetof(Impl_, p_db_lookup_after_),
           reinterpret_cast<const char*>(&from._impl_) +
               offsetof(Impl_, p_db_lookup_after_),
           offsetof(Impl_, p_db_lookup_before_) -
               offsetof(Impl_, p_db_lookup_after_) +
               sizeof(Impl_::p_db_lookup_before_));
  _impl_.p_update_every_ = from._impl_.p_update_every_;

  // @@protoc_insertion_point(copy_constructor:alarms.v1.AlarmConfiguration)
}
PROTOBUF_NDEBUG_INLINE AlarmConfiguration::Impl_::Impl_(
    [[maybe_unused]] ::google::protobuf::internal::InternalVisibility visibility,
    [[maybe_unused]] ::google::protobuf::Arena* PROTOBUF_NULLABLE arena)
      : _cached_size_{0},
        alarm_(arena),
        template__(arena),
        on_chart_(arena),
        classification_(arena),
        type_(arena),
        component_(arena),
        os_(arena),
        hosts_(arena),
        plugin_(arena),
        module_(arena),
        charts_(arena),
        families_(arena),
        lookup_(arena),
        every_(arena),
        units_(arena),
        green_(arena),
        red_(arena),
        calculation_expr_(arena),
        warning_expr_(arena),
        critical_expr_(arena),
        recipient_(arena),
        exec_(arena),
        delay_(arena),
        repeat_(arena),
        info_(arena),
        options_(arena),
        host_labels_(arena),
        p_db_lookup_dimensions_(arena),
        p_db_lookup_method_(arena),
        p_db_lookup_options_(arena),
        chart_labels_(arena),
        summary_(arena) {}

inline void AlarmConfiguration::SharedCtor(::_pb::Arena* PROTOBUF_NULLABLE arena) {
  new (&_impl_) Impl_(internal_visibility(), arena);
  ::memset(reinterpret_cast<char*>(&_impl_) +
               offsetof(Impl_, p_db_lookup_after_),
           0,
           offsetof(Impl_, p_db_lookup_before_) -
               offsetof(Impl_, p_db_lookup_after_) +
               sizeof(Impl_::p_db_lookup_before_));
  _impl_.p_update_every_ = {};
}
AlarmConfiguration::~AlarmConfiguration() {
  // @@protoc_insertion_point(destructor:alarms.v1.AlarmConfiguration)
  SharedDtor(*this);
}
inline void AlarmConfiguration::SharedDtor(MessageLite& self) {
  AlarmConfiguration& this_ = static_cast<AlarmConfiguration&>(self);
  if constexpr (::_pbi::DebugHardenCheckHasBitConsistency()) {
    this_.CheckHasBitConsistency();
  }
  this_._internal_metadata_.Delete<::google::protobuf::UnknownFieldSet>();
  ABSL_DCHECK(this_.GetArena() == nullptr);
  this_._impl_.alarm_.Destroy();
  this_._impl_.template__.Destroy();
  this_._impl_.on_chart_.Destroy();
  this_._impl_.classification_.Destroy();
  this_._impl_.type_.Destroy();
  this_._impl_.component_.Destroy();
  this_._impl_.os_.Destroy();
  this_._impl_.hosts_.Destroy();
  this_._impl_.plugin_.Destroy();
  this_._impl_.module_.Destroy();
  this_._impl_.charts_.Destroy();
  this_._impl_.families_.Destroy();
  this_._impl_.lookup_.Destroy();
  this_._impl_.every_.Destroy();
  this_._impl_.units_.Destroy();
  this_._impl_.green_.Destroy();
  this_._impl_.red_.Destroy();
  this_._impl_.calculation_expr_.Destroy();
  this_._impl_.warning_expr_.Destroy();
  this_._impl_.critical_expr_.Destroy();
  this_._impl_.recipient_.Destroy();
  this_._impl_.exec_.Destroy();
  this_._impl_.delay_.Destroy();
  this_._impl_.repeat_.Destroy();
  this_._impl_.info_.Destroy();
  this_._impl_.options_.Destroy();
  this_._impl_.host_labels_.Destroy();
  this_._impl_.p_db_lookup_dimensions_.Destroy();
  this_._impl_.p_db_lookup_method_.Destroy();
  this_._impl_.p_db_lookup_options_.Destroy();
  this_._impl_.chart_labels_.Destroy();
  this_._impl_.summary_.Destroy();
  this_._impl_.~Impl_();
}

#ifndef PROTOBUF_MESSAGE_GLOBALS
PROTOBUF_CONSTINIT PROTOBUF_ATTRIBUTE_INIT_PRIORITY1 const
    ::google::protobuf::internal::ClassDataFull AlarmConfiguration_class_data_ =
        AlarmConfiguration::InternalGenerateClassData_(AlarmConfiguration_globals_._default);

PROTOBUF_ATTRIBUTE_WEAK const ::google::protobuf::internal::ClassData* PROTOBUF_NONNULL
AlarmConfiguration::GetClassData() const {
  ::google::protobuf::internal::PrefetchToLocalCache(&AlarmConfiguration_class_data_);
  ::google::protobuf::internal::PrefetchToLocalCache(AlarmConfiguration_class_data_.tc_table);
  return AlarmConfiguration_class_data_.base();
}
#else
PROTOBUF_ATTRIBUTE_WEAK const ::google::protobuf::internal::ClassData* PROTOBUF_NONNULL
AlarmConfiguration::GetClassData() const {
  ::google::protobuf::internal::PrefetchToLocalCache(&AlarmConfiguration_globals_);
  ::google::protobuf::internal::PrefetchToLocalCache(
      ::google::protobuf::internal::MessageGlobalsBase::ToParseTableBase(&AlarmConfiguration_globals_));
  return AlarmConfiguration_globals_.GetClassData();
}
#endif  // !PROTOBUF_MESSAGE_GLOBALS
#ifndef PROTOBUF_MESSAGE_GLOBALS
PROTOBUF_CONSTINIT
PROTOBUF_ATTRIBUTE_INIT_PRIORITY1 const AlarmConfiguration::ParseTableT_
    AlarmConfiguration::_table_ =
        AlarmConfiguration::InternalGenerateParseTable_(AlarmConfiguration_class_data_.base());
#endif  // !PROTOBUF_MESSAGE_GLOBALS
PROTOBUF_NOINLINE void AlarmConfiguration::Clear() {
// @@protoc_insertion_point(message_clear_start:alarms.v1.AlarmConfiguration)
  ::google::protobuf::internal::TSanWrite(&_impl_);
  ::uint32_t cached_has_bits = 0;
  // Prevent compiler warnings about cached_has_bits being unused
  (void) cached_has_bits;

  cached_has_bits = _impl_._has_bits_[0];
  if (BatchCheckHasBit(cached_has_bits, 0x000000ffU)) {
    if (CheckHasBit(cached_has_bits, 0x00000001U)) {
      _impl_.alarm_.ClearNonDefaultToEmpty();
    }
    if (CheckHasBit(cached_has_bits, 0x00000002U)) {
      _impl_.template__.ClearNonDefaultToEmpty();
    }
    if (CheckHasBit(cached_has_bits, 0x00000004U)) {
      _impl_.on_chart_.ClearNonDefaultToEmpty();
    }
    if (CheckHasBit(cached_has_bits, 0x00000008U)) {
      _impl_.classification_.ClearNonDefaultToEmpty();
    }
    if (CheckHasBit(cached_has_bits, 0x00000010U)) {
      _impl_.type_.ClearNonDefaultToEmpty();
    }
    if (CheckHasBit(cached_has_bits, 0x00000020U)) {
      _impl_.component_.ClearNonDefaultToEmpty();
    }
    if (CheckHasBit(cached_has_bits, 0x00000040U)) {
      _impl_.os_.ClearNonDefaultToEmpty();
    }
    if (CheckHasBit(cached_has_bits, 0x00000080U)) {
      _impl_.hosts_.ClearNonDefaultToEmpty();
    }
  }
  if (BatchCheckHasBit(cached_has_bits, 0x0000ff00U)) {
    if (CheckHasBit(cached_has_bits, 0x00000100U)) {
      _impl_.plugin_.ClearNonDefaultToEmpty();
    }
    if (CheckHasBit(cached_has_bits, 0x00000200U)) {
      _impl_.module_.ClearNonDefaultToEmpty();
    }
    if (CheckHasBit(cached_has_bits, 0x00000400U)) {
      _impl_.charts_.ClearNonDefaultToEmpty();
    }
    if (CheckHasBit(cached_has_bits, 0x00000800U)) {
      _impl_.families_.ClearNonDefaultToEmpty();
    }
    if (CheckHasBit(cached_has_bits, 0x00001000U)) {
      _impl_.lookup_.ClearNonDefaultToEmpty();
    }
    if (CheckHasBit(cached_has_bits, 0x00002000U)) {
      _impl_.every_.ClearNonDefaultToEmpty();
    }
    if (CheckHasBit(cached_has_bits, 0x00004000U)) {
      _impl_.units_.ClearNonDefaultToEmpty();
    }
    if (CheckHasBit(cached_has_bits, 0x00008000U)) {
      _impl_.green_.ClearNonDefaultToEmpty();
    }
  }
  if (BatchCheckHasBit(cached_has_bits, 0x00ff0000U)) {
    if (CheckHasBit(cached_has_bits, 0x00010000U)) {
      _impl_.red_.ClearNonDefaultToEmpty();
    }
    if (CheckHasBit(cached_has_bits, 0x00020000U)) {
      _impl_.calculation_expr_.ClearNonDefaultToEmpty();
    }
    if (CheckHasBit(cached_has_bits, 0x00040000U)) {
      _impl_.warning_expr_.ClearNonDefaultToEmpty();
    }
    if (CheckHasBit(cached_has_bits, 0x00080000U)) {
      _impl_.critical_expr_.ClearNonDefaultToEmpty();
    }
    if (CheckHasBit(cached_has_bits, 0x00100000U)) {
      _impl_.recipient_.ClearNonDefaultToEmpty();
    }
    if (CheckHasBit(cached_has_bits, 0x00200000U)) {
      _impl_.exec_.ClearNonDefaultToEmpty();
    }
    if (CheckHasBit(cached_has_bits, 0x00400000U)) {
      _impl_.delay_.ClearNonDefaultToEmpty();
    }
    if (CheckHasBit(cached_has_bits, 0x00800000U)) {
      _impl_.repeat_.ClearNonDefaultToEmpty();
    }
  }
  if (BatchCheckHasBit(cached_has_bits, 0x1f000000U)) {
    if (CheckHasBit(cached_has_bits, 0x01000000U)) {
      _impl_.info_.ClearNonDefaultToEmpty();
    }
    if (CheckHasBit(cached_has_bits, 0x02000000U)) {
      _impl_.options_.ClearNonDefaultToEmpty();
    }
    if (CheckHasBit(cached_has_bits, 0x04000000U)) {
      _impl_.host_labels_.ClearNonDefaultToEmpty();
    }
    if (CheckHasBit(cached_has_bits, 0x08000000U)) {
      _impl_.p_db_lookup_dimensions_.ClearNonDefaultToEmpty();
    }
    if (CheckHasBit(cached_has_bits, 0x10000000U)) {
      _impl_.p_db_lookup_method_.ClearNonDefaultToEmpty();
    }
  }
  if (BatchCheckHasBit(cached_has_bits, 0xe0000000U)) {
    ::memset(&_impl_.p_db_lookup_after_, 0, static_cast<::size_t>(
        reinterpret_cast<char*>(&_impl_.p_db_lookup_before_) -
        reinterpret_cast<char*>(&_impl_.p_db_lookup_after_)) + sizeof(_impl_.p_db_lookup_before_));
    if (CheckHasBit(cached_has_bits, 0x80000000U)) {
      _impl_.p_db_lookup_options_.ClearNonDefaultToEmpty();
    }
  }
  cached_has_bits = _impl_._has_bits_[1];
  if (BatchCheckHasBit(cached_has_bits, 0x00000003U)) {
    if (CheckHasBit(cached_has_bits, 0x00000001U)) {
      _impl_.chart_labels_.ClearNonDefaultToEmpty();
    }
    if (CheckHasBit(cached_has_bits, 0x00000002U)) {
      _impl_.summary_.ClearNonDefaultToEmpty();
    }
  }
  _impl_.p_update_every_ = 0;
  _impl_._has_bits_.Clear();
  _internal_metadata_.Clear<::google::protobuf::UnknownFieldSet>();
}

#if defined(PROTOBUF_CUSTOM_VTABLE)
::uint8_t* PROTOBUF_NONNULL AlarmConfiguration::_InternalSerialize(
    const ::google::protobuf::MessageLite& base, ::uint8_t* PROTOBUF_NONNULL target,
    ::google::protobuf::io::EpsCopyOutputStream* PROTOBUF_NONNULL stream) {
  const AlarmConfiguration& this_ = static_cast<const AlarmConfiguration&>(base);
#else   // PROTOBUF_CUSTOM_VTABLE
::uint8_t* PROTOBUF_NONNULL AlarmConfiguration::_InternalSerialize(
    ::uint8_t* PROTOBUF_NONNULL target,
    ::google::protobuf::io::EpsCopyOutputStream* PROTOBUF_NONNULL stream) const {
  const AlarmConfiguration& this_ = *this;
#endif  // PROTOBUF_CUSTOM_VTABLE
  if constexpr (::_pbi::DebugHardenCheckHasBitConsistency()) {
    this_.CheckHasBitConsistency();
  }
  // @@protoc_insertion_point(serialize_to_array_start:alarms.v1.AlarmConfiguration)
  ::uint32_t cached_has_bits = 0;
  (void)cached_has_bits;

  cached_has_bits = this_._impl_._has_bits_[0];
  // string alarm = 1;
  if (CheckHasBit(cached_has_bits, 0x00000001U)) {
    if (!this_._internal_alarm().empty()) {
      const ::std::string& _s = this_._internal_alarm();
      ::google::protobuf::internal::WireFormatLite::VerifyUtf8String(
          _s.data(), static_cast<int>(_s.length()), ::google::protobuf::internal::WireFormatLite::SERIALIZE, "alarms.v1.AlarmConfiguration.alarm");
      target = stream->WriteStringMaybeAliased(1, _s, target);
    }
  }

  // string template = 2;
  if (CheckHasBit(cached_has_bits, 0x00000002U)) {
    if (!this_._internal_template_().empty()) {
      const ::std::string& _s = this_._internal_template_();
      ::google::protobuf::internal::WireFormatLite::VerifyUtf8String(
          _s.data(), static_cast<int>(_s.length()), ::google::protobuf::internal::WireFormatLite::SERIALIZE, "alarms.v1.AlarmConfiguration.template");
      target = stream->WriteStringMaybeAliased(2, _s, target);
    }
  }

  // string on_chart = 3;
  if (CheckHasBit(cached_has_bits, 0x00000004U)) {
    if (!this_._internal_on_chart().empty()) {
      const ::std::string& _s = this_._internal_on_chart();
      ::google::protobuf::internal::WireFormatLite::VerifyUtf8String(
          _s.data(), static_cast<int>(_s.length()), ::google::protobuf::internal::WireFormatLite::SERIALIZE, "alarms.v1.AlarmConfiguration.on_chart");
      target = stream->WriteStringMaybeAliased(3, _s, target);
    }
  }

  // string classification = 4;
  if (CheckHasBit(cached_has_bits, 0x00000008U)) {
    if (!this_._internal_classification().empty()) {
      const ::std::string& _s = this_._internal_classification();
      ::google::protobuf::internal::WireFormatLite::VerifyUtf8String(
          _s.data(), static_cast<int>(_s.length()), ::google::protobuf::internal::WireFormatLite::SERIALIZE, "alarms.v1.AlarmConfiguration.classification");
      target = stream->WriteStringMaybeAliased(4, _s, target);
    }
  }

  // string type = 5;
  if (CheckHasBit(cached_has_bits, 0x00000010U)) {
    if (!this_._internal_type().empty()) {
      const ::std::string& _s = this_._internal_type();
      ::google::protobuf::internal::WireFormatLite::VerifyUtf8String(
          _s.data(), static_cast<int>(_s.length()), ::google::protobuf::internal::WireFormatLite::SERIALIZE, "alarms.v1.AlarmConfiguration.type");
      target = stream->WriteStringMaybeAliased(5, _s, target);
    }
  }

  // string component = 6;
  if (CheckHasBit(cached_has_bits, 0x00000020U)) {
    if (!this_._internal_component().empty()) {
      const ::std::string& _s = this_._internal_component();
      ::google::protobuf::internal::WireFormatLite::VerifyUtf8String(
          _s.data(), static_cast<int>(_s.length()), ::google::protobuf::internal::WireFormatLite::SERIALIZE, "alarms.v1.AlarmConfiguration.component");
      target = stream->WriteStringMaybeAliased(6, _s, target);
    }
  }

  // string os = 7;
  if (CheckHasBit(cached_has_bits, 0x00000040U)) {
    if (!this_._internal_os().empty()) {
      const ::std::string& _s = this_._internal_os();
      ::google::protobuf::internal::WireFormatLite::VerifyUtf8String(
          _s.data(), static_cast<int>(_s.length()), ::google::protobuf::internal::WireFormatLite::SERIALIZE, "alarms.v1.AlarmConfiguration.os");
      target = stream->WriteStringMaybeAliased(7, _s, target);
    }
  }

  // string hosts = 8;
  if (CheckHasBit(cached_has_bits, 0x00000080U)) {
    if (!this_._internal_hosts().empty()) {
      const ::std::string& _s = this_._internal_hosts();
      ::google::protobuf::internal::WireFormatLite::VerifyUtf8String(
          _s.data(), static_cast<int>(_s.length()), ::google::protobuf::internal::WireFormatLite::SERIALIZE, "alarms.v1.AlarmConfiguration.hosts");
      target = stream->WriteStringMaybeAliased(8, _s, target);
    }
  }

  // string plugin = 9;
  if (CheckHasBit(cached_has_bits, 0x00000100U)) {
    if (!this_._internal_plugin().empty()) {
      const ::std::string& _s = this_._internal_plugin();
      ::google::protobuf::internal::WireFormatLite::VerifyUtf8String(
          _s.data(), static_cast<int>(_s.length()), ::google::protobuf::internal::WireFormatLite::SERIALIZE, "alarms.v1.AlarmConfiguration.plugin");
      target = stream->WriteStringMaybeAliased(9, _s, target);
    }
  }

  // string module = 10;
  if (CheckHasBit(cached_has_bits, 0x00000200U)) {
    if (!this_._internal_module().empty()) {
      const ::std::string& _s = this_._internal_module();
      ::google::protobuf::internal::WireFormatLite::VerifyUtf8String(
          _s.data(), static_cast<int>(_s.length()), ::google::protobuf::internal::WireFormatLite::SERIALIZE, "alarms.v1.AlarmConfiguration.module");
      target = stream->WriteStringMaybeAliased(10, _s, target);
    }
  }

  // string charts = 11;
  if (CheckHasBit(cached_has_bits, 0x00000400U)) {
    if (!this_._internal_charts().empty()) {
      const ::std::string& _s = this_._internal_charts();
      ::google::protobuf::internal::WireFormatLite::VerifyUtf8String(
          _s.data(), static_cast<int>(_s.length()), ::google::protobuf::internal::WireFormatLite::SERIALIZE, "alarms.v1.AlarmConfiguration.charts");
      target = stream->WriteStringMaybeAliased(11, _s, target);
    }
  }

  // string families = 12 [deprecated = true];
  if (CheckHasBit(cached_has_bits, 0x00000800U)) {
    if (!this_._internal_families().empty()) {
      const ::std::string& _s = this_._internal_families();
      ::google::protobuf::internal::WireFormatLite::VerifyUtf8String(
          _s.data(), static_cast<int>(_s.length()), ::google::protobuf::internal::WireFormatLite::SERIALIZE, "alarms.v1.AlarmConfiguration.families");
      target = stream->WriteStringMaybeAliased(12, _s, target);
    }
  }

  // string lookup = 13;
  if (CheckHasBit(cached_has_bits, 0x00001000U)) {
    if (!this_._internal_lookup().empty()) {
      const ::std::string& _s = this_._internal_lookup();
      ::google::protobuf::internal::WireFormatLite::VerifyUtf8String(
          _s.data(), static_cast<int>(_s.length()), ::google::protobuf::internal::WireFormatLite::SERIALIZE, "alarms.v1.AlarmConfiguration.lookup");
      target = stream->WriteStringMaybeAliased(13, _s, target);
    }
  }

  // string every = 14;
  if (CheckHasBit(cached_has_bits, 0x00002000U)) {
    if (!this_._internal_every().empty()) {
      const ::std::string& _s = this_._internal_every();
      ::google::protobuf::internal::WireFormatLite::VerifyUtf8String(
          _s.data(), static_cast<int>(_s.length()), ::google::protobuf::internal::WireFormatLite::SERIALIZE, "alarms.v1.AlarmConfiguration.every");
      target = stream->WriteStringMaybeAliased(14, _s, target);
    }
  }

  // string units = 15;
  if (CheckHasBit(cached_has_bits, 0x00004000U)) {
    if (!this_._internal_units().empty()) {
      const ::std::string& _s = this_._internal_units();
      ::google::protobuf::internal::WireFormatLite::VerifyUtf8String(
          _s.data(), static_cast<int>(_s.length()), ::google::protobuf::internal::WireFormatLite::SERIALIZE, "alarms.v1.AlarmConfiguration.units");
      target = stream->WriteStringMaybeAliased(15, _s, target);
    }
  }

  // string green = 16;
  if (CheckHasBit(cached_has_bits, 0x00008000U)) {
    if (!this_._internal_green().empty()) {
      const ::std::string& _s = this_._internal_green();
      ::google::protobuf::internal::WireFormatLite::VerifyUtf8String(
          _s.data(), static_cast<int>(_s.length()), ::google::protobuf::internal::WireFormatLite::SERIALIZE, "alarms.v1.AlarmConfiguration.green");
      target = stream->WriteStringMaybeAliased(16, _s, target);
    }
  }

  // string red = 17;
  if (CheckHasBit(cached_has_bits, 0x00010000U)) {
    if (!this_._internal_red().empty()) {
      const ::std::string& _s = this_._internal_red();
      ::google::protobuf::internal::WireFormatLite::VerifyUtf8String(
          _s.data(), static_cast<int>(_s.length()), ::google::protobuf::internal::WireFormatLite::SERIALIZE, "alarms.v1.AlarmConfiguration.red");
      target = stream->WriteStringMaybeAliased(17, _s, target);
    }
  }

  // string calculation_expr = 18;
  if (CheckHasBit(cached_has_bits, 0x00020000U)) {
    if (!this_._internal_calculation_expr().empty()) {
      const ::std::string& _s = this_._internal_calculation_expr();
      ::google::protobuf::internal::WireFormatLite::VerifyUtf8String(
          _s.data(), static_cast<int>(_s.length()), ::google::protobuf::internal::WireFormatLite::SERIALIZE, "alarms.v1.AlarmConfiguration.calculation_expr");
      target = stream->WriteStringMaybeAliased(18, _s, target);
    }
  }

  // string warning_expr = 19;
  if (CheckHasBit(cached_has_bits, 0x00040000U)) {
    if (!this_._internal_warning_expr().empty()) {
      const ::std::string& _s = this_._internal_warning_expr();
      ::google::protobuf::internal::WireFormatLite::VerifyUtf8String(
          _s.data(), static_cast<int>(_s.length()), ::google::protobuf::internal::WireFormatLite::SERIALIZE, "alarms.v1.AlarmConfiguration.warning_expr");
      target = stream->WriteStringMaybeAliased(19, _s, target);
    }
  }

  // string critical_expr = 20;
  if (CheckHasBit(cached_has_bits, 0x00080000U)) {
    if (!this_._internal_critical_expr().empty()) {
      const ::std::string& _s = this_._internal_critical_expr();
      ::google::protobuf::internal::WireFormatLite::VerifyUtf8String(
          _s.data(), static_cast<int>(_s.length()), ::google::protobuf::internal::WireFormatLite::SERIALIZE, "alarms.v1.AlarmConfiguration.critical_expr");
      target = stream->WriteStringMaybeAliased(20, _s, target);
    }
  }

  // string recipient = 21;
  if (CheckHasBit(cached_has_bits, 0x00100000U)) {
    if (!this_._internal_recipient().empty()) {
      const ::std::string& _s = this_._internal_recipient();
      ::google::protobuf::internal::WireFormatLite::VerifyUtf8String(
          _s.data(), static_cast<int>(_s.length()), ::google::protobuf::internal::WireFormatLite::SERIALIZE, "alarms.v1.AlarmConfiguration.recipient");
      target = stream->WriteStringMaybeAliased(21, _s, target);
    }
  }

  // string exec = 22;
  if (CheckHasBit(cached_has_bits, 0x00200000U)) {
    if (!this_._internal_exec().empty()) {
      const ::std::string& _s = this_._internal_exec();
      ::google::protobuf::internal::WireFormatLite::VerifyUtf8String(
          _s.data(), static_cast<int>(_s.length()), ::google::protobuf::internal::WireFormatLite::SERIALIZE, "alarms.v1.AlarmConfiguration.exec");
      target = stream->WriteStringMaybeAliased(22, _s, target);
    }
  }

  // string delay = 23;
  if (CheckHasBit(cached_has_bits, 0x00400000U)) {
    if (!this_._internal_delay().empty()) {
      const ::std::string& _s = this_._internal_delay();
      ::google::protobuf::internal::WireFormatLite::VerifyUtf8String(
          _s.data(), static_cast<int>(_s.length()), ::google::protobuf::internal::WireFormatLite::SERIALIZE, "alarms.v1.AlarmConfiguration.delay");
      target = stream->WriteStringMaybeAliased(23, _s, target);
    }
  }

  // string repeat = 24;
  if (CheckHasBit(cached_has_bits, 0x00800000U)) {
    if (!this_._internal_repeat().empty()) {
      const ::std::string& _s = this_._internal_repeat();
      ::google::protobuf::internal::WireFormatLite::VerifyUtf8String(
          _s.data(), static_cast<int>(_s.length()), ::google::protobuf::internal::WireFormatLite::SERIALIZE, "alarms.v1.AlarmConfiguration.repeat");
      target = stream->WriteStringMaybeAliased(24, _s, target);
    }
  }

  // string info = 25;
  if (CheckHasBit(cached_has_bits, 0x01000000U)) {
    if (!this_._internal_info().empty()) {
      const ::std::string& _s = this_._internal_info();
      ::google::protobuf::internal::WireFormatLite::VerifyUtf8String(
          _s.data(), static_cast<int>(_s.length()), ::google::protobuf::internal::WireFormatLite::SERIALIZE, "alarms.v1.AlarmConfiguration.info");
      target = stream->WriteStringMaybeAliased(25, _s, target);
    }
  }

  // string options = 26;
  if (CheckHasBit(cached_has_bits, 0x02000000U)) {
    if (!this_._internal_options().empty()) {
      const ::std::string& _s = this_._internal_options();
      ::google::protobuf::internal::WireFormatLite::VerifyUtf8String(
          _s.data(), static_cast<int>(_s.length()), ::google::protobuf::internal::WireFormatLite::SERIALIZE, "alarms.v1.AlarmConfiguration.options");
      target = stream->WriteStringMaybeAliased(26, _s, target);
    }
  }

  // string host_labels = 27;
  if (CheckHasBit(cached_has_bits, 0x04000000U)) {
    if (!this_._internal_host_labels().empty()) {
      const ::std::string& _s = this_._internal_host_labels();
      ::google::protobuf::internal::WireFormatLite::VerifyUtf8String(
          _s.data(), static_cast<int>(_s.length()), ::google::protobuf::internal::WireFormatLite::SERIALIZE, "alarms.v1.AlarmConfiguration.host_labels");
      target = stream->WriteStringMaybeAliased(27, _s, target);
    }
  }

  // int32 p_db_lookup_after = 28;
  if (CheckHasBit(cached_has_bits, 0x20000000U)) {
    if (this_._internal_p_db_lookup_after() != 0) {
      target = stream->EnsureSpace(target);
      target = ::_pbi::WireFormatLite::WriteInt32ToArray(
          28, this_._internal_p_db_lookup_after(), target);
    }
  }

  // int32 p_db_lookup_before = 29;
  if (CheckHasBit(cached_has_bits, 0x40000000U)) {
    if (this_._internal_p_db_lookup_before() != 0) {
      target = stream->EnsureSpace(target);
      target = ::_pbi::WireFormatLite::WriteInt32ToArray(
          29, this_._internal_p_db_lookup_before(), target);
    }
  }

  // string p_db_lookup_dimensions = 30;
  if (CheckHasBit(cached_has_bits, 0x08000000U)) {
    if (!this_._internal_p_db_lookup_dimensions().empty()) {
      const ::std::string& _s = this_._internal_p_db_lookup_dimensions();
      ::google::protobuf::internal::WireFormatLite::VerifyUtf8String(
          _s.data(), static_cast<int>(_s.length()), ::google::protobuf::internal::WireFormatLite::SERIALIZE, "alarms.v1.AlarmConfiguration.p_db_lookup_dimensions");
      target = stream->WriteStringMaybeAliased(30, _s, target);
    }
  }

  // string p_db_lookup_method = 31;
  if (CheckHasBit(cached_has_bits, 0x10000000U)) {
    if (!this_._internal_p_db_lookup_method().empty()) {
      const ::std::string& _s = this_._internal_p_db_lookup_method();
      ::google::protobuf::internal::WireFormatLite::VerifyUtf8String(
          _s.data(), static_cast<int>(_s.length()), ::google::protobuf::internal::WireFormatLite::SERIALIZE, "alarms.v1.AlarmConfiguration.p_db_lookup_method");
      target = stream->WriteStringMaybeAliased(31, _s, target);
    }
  }

  // string p_db_lookup_options = 32;
  if (CheckHasBit(cached_has_bits, 0x80000000U)) {
    if (!this_._internal_p_db_lookup_options().empty()) {
      const ::std::string& _s = this_._internal_p_db_lookup_options();
      ::google::protobuf::internal::WireFormatLite::VerifyUtf8String(
          _s.data(), static_cast<int>(_s.length()), ::google::protobuf::internal::WireFormatLite::SERIALIZE, "alarms.v1.AlarmConfiguration.p_db_lookup_options");
      target = stream->WriteStringMaybeAliased(32, _s, target);
    }
  }

  cached_has_bits = this_._impl_._has_bits_[1];
  // int32 p_update_every = 33;
  if (CheckHasBit(cached_has_bits, 0x00000004U)) {
    if (this_._internal_p_update_every() != 0) {
      target = stream->EnsureSpace(target);
      target = ::_pbi::WireFormatLite::WriteInt32ToArray(
          33, this_._internal_p_update_every(), target);
    }
  }

  // string chart_labels = 34;
  if (CheckHasBit(cached_has_bits, 0x00000001U)) {
    if (!this_._internal_chart_labels().empty()) {
      const ::std::string& _s = this_._internal_chart_labels();
      ::google::protobuf::internal::WireFormatLite::VerifyUtf8String(
          _s.data(), static_cast<int>(_s.length()), ::google::protobuf::internal::WireFormatLite::SERIALIZE, "alarms.v1.AlarmConfiguration.chart_labels");
      target = stream->WriteStringMaybeAliased(34, _s, target);
    }
  }

  // string summary = 35;
  if (CheckHasBit(cached_has_bits, 0x00000002U)) {
    if (!this_._internal_summary().empty()) {
      const ::std::string& _s = this_._internal_summary();
      ::google::protobuf::internal::WireFormatLite::VerifyUtf8String(
          _s.data(), static_cast<int>(_s.length()), ::google::protobuf::internal::WireFormatLite::SERIALIZE, "alarms.v1.AlarmConfiguration.summary");
      target = stream->WriteStringMaybeAliased(35, _s, target);
    }
  }

  if (ABSL_PREDICT_FALSE(this_._internal_metadata_.have_unknown_fields())) {
    target =
        ::_pbi::WireFormat::InternalSerializeUnknownFieldsToArray(
            this_._internal_metadata_.unknown_fields<::google::protobuf::UnknownFieldSet>(::google::protobuf::UnknownFieldSet::default_instance), target, stream);
  }
  // @@protoc_insertion_point(serialize_to_array_end:alarms.v1.AlarmConfiguration)
  return target;
}

#if defined(PROTOBUF_CUSTOM_VTABLE)
::size_t AlarmConfiguration::ByteSizeLong(const MessageLite& base) {
  const AlarmConfiguration& this_ = static_cast<const AlarmConfiguration&>(base);
#else   // PROTOBUF_CUSTOM_VTABLE
::size_t AlarmConfiguration::ByteSizeLong() const {
  const AlarmConfiguration& this_ = *this;
#endif  // PROTOBUF_CUSTOM_VTABLE
  // @@protoc_insertion_point(message_byte_size_start:alarms.v1.AlarmConfiguration)
  ::size_t total_size = 0;

  ::uint32_t cached_has_bits = 0;
  // Prevent compiler warnings about cached_has_bits being unused
  (void)cached_has_bits;

  ::_pbi::Prefetch5LinesFrom7Lines(&this_);
  cached_has_bits = this_._impl_._has_bits_[0];
  if (BatchCheckHasBit(cached_has_bits, 0x000000ffU)) {
    // string alarm = 1;
    if (CheckHasBit(cached_has_bits, 0x00000001U)) {
      if (!this_._internal_alarm().empty()) {
        total_size += 1 + ::google::protobuf::internal::WireFormatLite::StringSize(
                                        this_._internal_alarm());
      }
    }
    // string template = 2;
    if (CheckHasBit(cached_has_bits, 0x00000002U)) {
      if (!this_._internal_template_().empty()) {
        total_size += 1 + ::google::protobuf::internal::WireFormatLite::StringSize(
                                        this_._internal_template_());
      }
    }
    // string on_chart = 3;
    if (CheckHasBit(cached_has_bits, 0x00000004U)) {
      if (!this_._internal_on_chart().empty()) {
        total_size += 1 + ::google::protobuf::internal::WireFormatLite::StringSize(
                                        this_._internal_on_chart());
      }
    }
    // string classification = 4;
    if (CheckHasBit(cached_has_bits, 0x00000008U)) {
      if (!this_._internal_classification().empty()) {
        total_size += 1 + ::google::protobuf::internal::WireFormatLite::StringSize(
                                        this_._internal_classification());
      }
    }
    // string type = 5;
    if (CheckHasBit(cached_has_bits, 0x00000010U)) {
      if (!this_._internal_type().empty()) {
        total_size += 1 + ::google::protobuf::internal::WireFormatLite::StringSize(
                                        this_._internal_type());
      }
    }
    // string component = 6;
    if (CheckHasBit(cached_has_bits, 0x00000020U)) {
      if (!this_._internal_component().empty()) {
        total_size += 1 + ::google::protobuf::internal::WireFormatLite::StringSize(
                                        this_._internal_component());
      }
    }
    // string os = 7;
    if (CheckHasBit(cached_has_bits, 0x00000040U)) {
      if (!this_._internal_os().empty()) {
        total_size += 1 + ::google::protobuf::internal::WireFormatLite::StringSize(
                                        this_._internal_os());
      }
    }
    // string hosts = 8;
    if (CheckHasBit(cached_has_bits, 0x00000080U)) {
      if (!this_._internal_hosts().empty()) {
        total_size += 1 + ::google::protobuf::internal::WireFormatLite::StringSize(
                                        this_._internal_hosts());
      }
    }
  }
  if (BatchCheckHasBit(cached_has_bits, 0x0000ff00U)) {
    // string plugin = 9;
    if (CheckHasBit(cached_has_bits, 0x00000100U)) {
      if (!this_._internal_plugin().empty()) {
        total_size += 1 + ::google::protobuf::internal::WireFormatLite::StringSize(
                                        this_._internal_plugin());
      }
    }
    // string module = 10;
    if (CheckHasBit(cached_has_bits, 0x00000200U)) {
      if (!this_._internal_module().empty()) {
        total_size += 1 + ::google::protobuf::internal::WireFormatLite::StringSize(
                                        this_._internal_module());
      }
    }
    // string charts = 11;
    if (CheckHasBit(cached_has_bits, 0x00000400U)) {
      if (!this_._internal_charts().empty()) {
        total_size += 1 + ::google::protobuf::internal::WireFormatLite::StringSize(
                                        this_._internal_charts());
      }
    }
    // string families = 12 [deprecated = true];
    if (CheckHasBit(cached_has_bits, 0x00000800U)) {
      if (!this_._internal_families().empty()) {
        total_size += 1 + ::google::protobuf::internal::WireFormatLite::StringSize(
                                        this_._internal_families());
      }
    }
    // string lookup = 13;
    if (CheckHasBit(cached_has_bits, 0x00001000U)) {
      if (!this_._internal_lookup().empty()) {
        total_size += 1 + ::google::protobuf::internal::WireFormatLite::StringSize(
                                        this_._internal_lookup());
      }
    }
    // string every = 14;
    if (CheckHasBit(cached_has_bits, 0x00002000U)) {
      if (!this_._internal_every().empty()) {
        total_size += 1 + ::google::protobuf::internal::WireFormatLite::StringSize(
                                        this_._internal_every());
      }
    }
    // string units = 15;
    if (CheckHasBit(cached_has_bits, 0x00004000U)) {
      if (!this_._internal_units().empty()) {
        total_size += 1 + ::google::protobuf::internal::WireFormatLite::StringSize(
                                        this_._internal_units());
      }
    }
    // string green = 16;
    if (CheckHasBit(cached_has_bits, 0x00008000U)) {
      if (!this_._internal_green().empty()) {
        total_size += 2 + ::google::protobuf::internal::WireFormatLite::StringSize(
                                        this_._internal_green());
      }
    }
  }
  if (BatchCheckHasBit(cached_has_bits, 0x00ff0000U)) {
    // string red = 17;
    if (CheckHasBit(cached_has_bits, 0x00010000U)) {
      if (!this_._internal_red().empty()) {
        total_size += 2 + ::google::protobuf::internal::WireFormatLite::StringSize(
                                        this_._internal_red());
      }
    }
    // string calculation_expr = 18;
    if (CheckHasBit(cached_has_bits, 0x00020000U)) {
      if (!this_._internal_calculation_expr().empty()) {
        total_size += 2 + ::google::protobuf::internal::WireFormatLite::StringSize(
                                        this_._internal_calculation_expr());
      }
    }
    // string warning_expr = 19;
    if (CheckHasBit(cached_has_bits, 0x00040000U)) {
      if (!this_._internal_warning_expr().empty()) {
        total_size += 2 + ::google::protobuf::internal::WireFormatLite::StringSize(
                                        this_._internal_warning_expr());
      }
    }
    // string critical_expr = 20;
    if (CheckHasBit(cached_has_bits, 0x00080000U)) {
      if (!this_._internal_critical_expr().empty()) {
        total_size += 2 + ::google::protobuf::internal::WireFormatLite::StringSize(
                                        this_._internal_critical_expr());
      }
    }
    // string recipient = 21;
    if (CheckHasBit(cached_has_bits, 0x00100000U)) {
      if (!this_._internal_recipient().empty()) {
        total_size += 2 + ::google::protobuf::internal::WireFormatLite::StringSize(
                                        this_._internal_recipient());
      }
    }
    // string exec = 22;
    if (CheckHasBit(cached_has_bits, 0x00200000U)) {
      if (!this_._internal_exec().empty()) {
        total_size += 2 + ::google::protobuf::internal::WireFormatLite::StringSize(
                                        this_._internal_exec());
      }
    }
    // string delay = 23;
    if (CheckHasBit(cached_has_bits, 0x00400000U)) {
      if (!this_._internal_delay().empty()) {
        total_size += 2 + ::google::protobuf::internal::WireFormatLite::StringSize(
                                        this_._internal_delay());
      }
    }
    // string repeat = 24;
    if (CheckHasBit(cached_has_bits, 0x00800000U)) {
      if (!this_._internal_repeat().empty()) {
        total_size += 2 + ::google::protobuf::internal::WireFormatLite::StringSize(
                                        this_._internal_repeat());
      }
    }
  }
  if (BatchCheckHasBit(cached_has_bits, 0xff000000U)) {
    // string info = 25;
    if (CheckHasBit(cached_has_bits, 0x01000000U)) {
      if (!this_._internal_info().empty()) {
        total_size += 2 + ::google::protobuf::internal::WireFormatLite::StringSize(
                                        this_._internal_info());
      }
    }
    // string options = 26;
    if (CheckHasBit(cached_has_bits, 0x02000000U)) {
      if (!this_._internal_options().empty()) {
        total_size += 2 + ::google::protobuf::internal::WireFormatLite::StringSize(
                                        this_._internal_options());
      }
    }
    // string host_labels = 27;
    if (CheckHasBit(cached_has_bits, 0x04000000U)) {
      if (!this_._internal_host_labels().empty()) {
        total_size += 2 + ::google::protobuf::internal::WireFormatLite::StringSize(
                                        this_._internal_host_labels());
      }
    }
    // string p_db_lookup_dimensions = 30;
    if (CheckHasBit(cached_has_bits, 0x08000000U)) {
      if (!this_._internal_p_db_lookup_dimensions().empty()) {
        total_size += 2 + ::google::protobuf::internal::WireFormatLite::StringSize(
                                        this_._internal_p_db_lookup_dimensions());
      }
    }
    // string p_db_lookup_method = 31;
    if (CheckHasBit(cached_has_bits, 0x10000000U)) {
      if (!this_._internal_p_db_lookup_method().empty()) {
        total_size += 2 + ::google::protobuf::internal::WireFormatLite::StringSize(
                                        this_._internal_p_db_lookup_method());
      }
    }
    // int32 p_db_lookup_after = 28;
    if (CheckHasBit(cached_has_bits, 0x20000000U)) {
      if (this_._internal_p_db_lookup_after() != 0) {
        total_size += 2 + ::_pbi::WireFormatLite::Int32Size(
                                        this_._internal_p_db_lookup_after());
      }
    }
    // int32 p_db_lookup_before = 29;
    if (CheckHasBit(cached_has_bits, 0x40000000U)) {
      if (this_._internal_p_db_lookup_before() != 0) {
        total_size += 2 + ::_pbi::WireFormatLite::Int32Size(
                                        this_._internal_p_db_lookup_before());
      }
    }
    // string p_db_lookup_options = 32;
    if (CheckHasBit(cached_has_bits, 0x80000000U)) {
      if (!this_._internal_p_db_lookup_options().empty()) {
        total_size += 2 + ::google::protobuf::internal::WireFormatLite::StringSize(
                                        this_._internal_p_db_lookup_options());
      }
    }
  }
  cached_has_bits = this_._impl_._has_bits_[1];
  if (BatchCheckHasBit(cached_has_bits, 0x00000007U)) {
    // string chart_labels = 34;
    if (CheckHasBit(cached_has_bits, 0x00000001U)) {
      if (!this_._internal_chart_labels().empty()) {
        total_size += 2 + ::google::protobuf::internal::WireFormatLite::StringSize(
                                        this_._internal_chart_labels());
      }
    }
    // string summary = 35;
    if (CheckHasBit(cached_has_bits, 0x00000002U)) {
      if (!this_._internal_summary().empty()) {
        total_size += 2 + ::google::protobuf::internal::WireFormatLite::StringSize(
                                        this_._internal_summary());
      }
    }
    // int32 p_update_every = 33;
    if (CheckHasBit(cached_has_bits, 0x00000004U)) {
      if (this_._internal_p_update_every() != 0) {
        total_size += 2 + ::_pbi::WireFormatLite::Int32Size(
                                        this_._internal_p_update_every());
      }
    }
  }
  return this_.MaybeComputeUnknownFieldsSize(total_size,
                                             &this_._impl_._cached_size_);
}

void AlarmConfiguration::MergeImpl(::google::protobuf::MessageLite& to_msg,
                      const ::google::protobuf::MessageLite& from_msg) {
   auto* const _this = static_cast<AlarmConfiguration*>(&to_msg);
  auto& from = static_cast<const AlarmConfiguration&>(from_msg);
  if constexpr (::_pbi::DebugHardenCheckHasBitConsistency()) {
    from.CheckHasBitConsistency();
  }
  // @@protoc_insertion_point(class_specific_merge_from_start:alarms.v1.AlarmConfiguration)
  ABSL_DCHECK_NE(&from, _this);
  ::uint32_t cached_has_bits = 0;
  (void)cached_has_bits;

  cached_has_bits = from._impl_._has_bits_[0];
  if (BatchCheckHasBit(cached_has_bits, 0x000000ffU)) {
    if (CheckHasBit(cached_has_bits, 0x00000001U)) {
      if (!from._internal_alarm().empty()) {
        _this->_internal_set_alarm(from._internal_alarm());
      } else {
        if (_this->_impl_.alarm_.IsDefault()) {
          _this->_internal_set_alarm("");
        }
      }
    }
    if (CheckHasBit(cached_has_bits, 0x00000002U)) {
      if (!from._internal_template_().empty()) {
        _this->_internal_set_template_(from._internal_template_());
      } else {
        if (_this->_impl_.template__.IsDefault()) {
          _this->_internal_set_template_("");
        }
      }
    }
    if (CheckHasBit(cached_has_bits, 0x00000004U)) {
      if (!from._internal_on_chart().empty()) {
        _this->_internal_set_on_chart(from._internal_on_chart());
      } else {
        if (_this->_impl_.on_chart_.IsDefault()) {
          _this->_internal_set_on_chart("");
        }
      }
    }
    if (CheckHasBit(cached_has_bits, 0x00000008U)) {
      if (!from._internal_classification().empty()) {
        _this->_internal_set_classification(from._internal_classification());
      } else {
        if (_this->_impl_.classification_.IsDefault()) {
          _this->_internal_set_classification("");
        }
      }
    }
    if (CheckHasBit(cached_has_bits, 0x00000010U)) {
      if (!from._internal_type().empty()) {
        _this->_internal_set_type(from._internal_type());
      } else {
        if (_this->_impl_.type_.IsDefault()) {
          _this->_internal_set_type("");
        }
      }
    }
    if (CheckHasBit(cached_has_bits, 0x00000020U)) {
      if (!from._internal_component().empty()) {
        _this->_internal_set_component(from._internal_component());
      } else {
        if (_this->_impl_.component_.IsDefault()) {
          _this->_internal_set_component("");
        }
      }
    }
    if (CheckHasBit(cached_has_bits, 0x00000040U)) {
      if (!from._internal_os().empty()) {
        _this->_internal_set_os(from._internal_os());
      } else {
        if (_this->_impl_.os_.IsDefault()) {
          _this->_internal_set_os("");
        }
      }
    }
    if (CheckHasBit(cached_has_bits, 0x00000080U)) {
      if (!from._internal_hosts().empty()) {
        _this->_internal_set_hosts(from._internal_hosts());
      } else {
        if (_this->_impl_.hosts_.IsDefault()) {
          _this->_internal_set_hosts("");
        }
      }
    }
  }
  if (BatchCheckHasBit(cached_has_bits, 0x0000ff00U)) {
    if (CheckHasBit(cached_has_bits, 0x00000100U)) {
      if (!from._internal_plugin().empty()) {
        _this->_internal_set_plugin(from._internal_plugin());
      } else {
        if (_this->_impl_.plugin_.IsDefault()) {
          _this->_internal_set_plugin("");
        }
      }
    }
    if (CheckHasBit(cached_has_bits, 0x00000200U)) {
      if (!from._internal_module().empty()) {
        _this->_internal_set_module(from._internal_module());
      } else {
        if (_this->_impl_.module_.IsDefault()) {
          _this->_internal_set_module("");
        }
      }
    }
    if (CheckHasBit(cached_has_bits, 0x00000400U)) {
      if (!from._internal_charts().empty()) {
        _this->_internal_set_charts(from._internal_charts());
      } else {
        if (_this->_impl_.charts_.IsDefault()) {
          _this->_internal_set_charts("");
        }
      }
    }
    if (CheckHasBit(cached_has_bits, 0x00000800U)) {
      if (!from._internal_families().empty()) {
        _this->_internal_set_families(from._internal_families());
      } else {
        if (_this->_impl_.families_.IsDefault()) {
          _this->_internal_set_families("");
        }
      }
    }
    if (CheckHasBit(cached_has_bits, 0x00001000U)) {
      if (!from._internal_lookup().empty()) {
        _this->_internal_set_lookup(from._internal_lookup());
      } else {
        if (_this->_impl_.lookup_.IsDefault()) {
          _this->_internal_set_lookup("");
        }
      }
    }
    if (CheckHasBit(cached_has_bits, 0x00002000U)) {
      if (!from._internal_every().empty()) {
        _this->_internal_set_every(from._internal_every());
      } else {
        if (_this->_impl_.every_.IsDefault()) {
          _this->_internal_set_every("");
        }
      }
    }
    if (CheckHasBit(cached_has_bits, 0x00004000U)) {
      if (!from._internal_units().empty()) {
        _this->_internal_set_units(from._internal_units());
      } else {
        if (_this->_impl_.units_.IsDefault()) {
          _this->_internal_set_units("");
        }
      }
    }
    if (CheckHasBit(cached_has_bits, 0x00008000U)) {
      if (!from._internal_green().empty()) {
        _this->_internal_set_green(from._internal_green());
      } else {
        if (_this->_impl_.green_.IsDefault()) {
          _this->_internal_set_green("");
        }
      }
    }
  }
  if (BatchCheckHasBit(cached_has_bits, 0x00ff0000U)) {
    if (CheckHasBit(cached_has_bits, 0x00010000U)) {
      if (!from._internal_red().empty()) {
        _this->_internal_set_red(from._internal_red());
      } else {
        if (_this->_impl_.red_.IsDefault()) {
          _this->_internal_set_red("");
        }
      }
    }
    if (CheckHasBit(cached_has_bits, 0x00020000U)) {
      if (!from._internal_calculation_expr().empty()) {
        _this->_internal_set_calculation_expr(from._internal_calculation_expr());
      } else {
        if (_this->_impl_.calculation_expr_.IsDefault()) {
          _this->_internal_set_calculation_expr("");
        }
      }
    }
    if (CheckHasBit(cached_has_bits, 0x00040000U)) {
      if (!from._internal_warning_expr().empty()) {
        _this->_internal_set_warning_expr(from._internal_warning_expr());
      } else {
        if (_this->_impl_.warning_expr_.IsDefault()) {
          _this->_internal_set_warning_expr("");
        }
      }
    }
    if (CheckHasBit(cached_has_bits, 0x00080000U)) {
      if (!from._internal_critical_expr().empty()) {
        _this->_internal_set_critical_expr(from._internal_critical_expr());
      } else {
        if (_this->_impl_.critical_expr_.IsDefault()) {
          _this->_internal_set_critical_expr("");
        }
      }
    }
    if (CheckHasBit(cached_has_bits, 0x00100000U)) {
      if (!from._internal_recipient().empty()) {
        _this->_internal_set_recipient(from._internal_recipient());
      } else {
        if (_this->_impl_.recipient_.IsDefault()) {
          _this->_internal_set_recipient("");
        }
      }
    }
    if (CheckHasBit(cached_has_bits, 0x00200000U)) {
      if (!from._internal_exec().empty()) {
        _this->_internal_set_exec(from._internal_exec());
      } else {
        if (_this->_impl_.exec_.IsDefault()) {
          _this->_internal_set_exec("");
        }
      }
    }
    if (CheckHasBit(cached_has_bits, 0x00400000U)) {
      if (!from._internal_delay().empty()) {
        _this->_internal_set_delay(from._internal_delay());
      } else {
        if (_this->_impl_.delay_.IsDefault()) {
          _this->_internal_set_delay("");
        }
      }
    }
    if (CheckHasBit(cached_has_bits, 0x00800000U)) {
      if (!from._internal_repeat().empty()) {
        _this->_internal_set_repeat(from._internal_repeat());
      } else {
        if (_this->_impl_.repeat_.IsDefault()) {
          _this->_internal_set_repeat("");
        }
      }
    }
  }
  if (BatchCheckHasBit(cached_has_bits, 0xff000000U)) {
    if (CheckHasBit(cached_has_bits, 0x01000000U)) {
      if (!from._internal_info().empty()) {
        _this->_internal_set_info(from._internal_info());
      } else {
        if (_this->_impl_.info_.IsDefault()) {
          _this->_internal_set_info("");
        }
      }
    }
    if (CheckHasBit(cached_has_bits, 0x02000000U)) {
      if (!from._internal_options().empty()) {
        _this->_internal_set_options(from._internal_options());
      } else {
        if (_this->_impl_.options_.IsDefault()) {
          _this->_internal_set_options("");
        }
      }
    }
    if (CheckHasBit(cached_has_bits, 0x04000000U)) {
      if (!from._internal_host_labels().empty()) {
        _this->_internal_set_host_labels(from._internal_host_labels());
      } else {
        if (_this->_impl_.host_labels_.IsDefault()) {
          _this->_internal_set_host_labels("");
        }
      }
    }
    if (CheckHasBit(cached_has_bits, 0x08000000U)) {
      if (!from._internal_p_db_lookup_dimensions().empty()) {
        _this->_internal_set_p_db_lookup_dimensions(from._internal_p_db_lookup_dimensions());
      } else {
        if (_this->_impl_.p_db_lookup_dimensions_.IsDefault()) {
          _this->_internal_set_p_db_lookup_dimensions("");
        }
      }
    }
    if (CheckHasBit(cached_has_bits, 0x10000000U)) {
      if (!from._internal_p_db_lookup_method().empty()) {
        _this->_internal_set_p_db_lookup_method(from._internal_p_db_lookup_method());
      } else {
        if (_this->_impl_.p_db_lookup_method_.IsDefault()) {
          _this->_internal_set_p_db_lookup_method("");
        }
      }
    }
    if (CheckHasBit(cached_has_bits, 0x20000000U)) {
      if (from._internal_p_db_lookup_after() != 0) {
        _this->_impl_.p_db_lookup_after_ = from._impl_.p_db_lookup_after_;
      }
    }
    if (CheckHasBit(cached_has_bits, 0x40000000U)) {
      if (from._internal_p_db_lookup_before() != 0) {
        _this->_impl_.p_db_lookup_before_ = from._impl_.p_db_lookup_before_;
      }
    }
    if (CheckHasBit(cached_has_bits, 0x80000000U)) {
      if (!from._internal_p_db_lookup_options().empty()) {
        _this->_internal_set_p_db_lookup_options(from._internal_p_db_lookup_options());
      } else {
        if (_this->_impl_.p_db_lookup_options_.IsDefault()) {
          _this->_internal_set_p_db_lookup_options("");
        }
      }
    }
  }
  cached_has_bits = from._impl_._has_bits_[1];
  if (BatchCheckHasBit(cached_has_bits, 0x00000007U)) {
    if (CheckHasBit(cached_has_bits, 0x00000001U)) {
      if (!from._internal_chart_labels().empty()) {
        _this->_internal_set_chart_labels(from._internal_chart_labels());
      } else {
        if (_this->_impl_.chart_labels_.IsDefault()) {
          _this->_internal_set_chart_labels("");
        }
      }
    }
    if (CheckHasBit(cached_has_bits, 0x00000002U)) {
      if (!from._internal_summary().empty()) {
        _this->_internal_set_summary(from._internal_summary());
      } else {
        if (_this->_impl_.summary_.IsDefault()) {
          _this->_internal_set_summary("");
        }
      }
    }
    if (CheckHasBit(cached_has_bits, 0x00000004U)) {
      if (from._internal_p_update_every() != 0) {
        _this->_impl_.p_update_every_ = from._impl_.p_update_every_;
      }
    }
  }
  _this->_impl_._has_bits_.Or(from._impl_._has_bits_);
  _this->_internal_metadata_.MergeFrom<::google::protobuf::UnknownFieldSet>(
      from._internal_metadata_);
}

void AlarmConfiguration::CopyFrom(const AlarmConfiguration& from) {
  // @@protoc_insertion_point(class_specific_copy_from_start:alarms.v1.AlarmConfiguration)
  if (&from == this) return;
  Clear();
  MergeFrom(from);
}


void AlarmConfiguration::InternalSwap(AlarmConfiguration* PROTOBUF_RESTRICT PROTOBUF_NONNULL other) {
  using ::std::swap;
  auto* arena = GetArena();
  ABSL_DCHECK_EQ(arena, other->GetArena());
  _internal_metadata_.InternalSwap(&other->_internal_metadata_);
  swap(_impl_._has_bits_[0], other->_impl_._has_bits_[0]);
  swap(_impl_._has_bits_[1], other->_impl_._has_bits_[1]);
  ::_pbi::ArenaStringPtr::InternalSwap(&_impl_.alarm_, &other->_impl_.alarm_, arena);
  ::_pbi::ArenaStringPtr::InternalSwap(&_impl_.template__, &other->_impl_.template__, arena);
  ::_pbi::ArenaStringPtr::InternalSwap(&_impl_.on_chart_, &other->_impl_.on_chart_, arena);
  ::_pbi::ArenaStringPtr::InternalSwap(&_impl_.classification_, &other->_impl_.classification_, arena);
  ::_pbi::ArenaStringPtr::InternalSwap(&_impl_.type_, &other->_impl_.type_, arena);
  ::_pbi::ArenaStringPtr::InternalSwap(&_impl_.component_, &other->_impl_.component_, arena);
  ::_pbi::ArenaStringPtr::InternalSwap(&_impl_.os_, &other->_impl_.os_, arena);
  ::_pbi::ArenaStringPtr::InternalSwap(&_impl_.hosts_, &other->_impl_.hosts_, arena);
  ::_pbi::ArenaStringPtr::InternalSwap(&_impl_.plugin_, &other->_impl_.plugin_, arena);
  ::_pbi::ArenaStringPtr::InternalSwap(&_impl_.module_, &other->_impl_.module_, arena);
  ::_pbi::ArenaStringPtr::InternalSwap(&_impl_.charts_, &other->_impl_.charts_, arena);
  ::_pbi::ArenaStringPtr::InternalSwap(&_impl_.families_, &other->_impl_.families_, arena);
  ::_pbi::ArenaStringPtr::InternalSwap(&_impl_.lookup_, &other->_impl_.lookup_, arena);
  ::_pbi::ArenaStringPtr::InternalSwap(&_impl_.every_, &other->_impl_.every_, arena);
  ::_pbi::ArenaStringPtr::InternalSwap(&_impl_.units_, &other->_impl_.units_, arena);
  ::_pbi::ArenaStringPtr::InternalSwap(&_impl_.green_, &other->_impl_.green_, arena);
  ::_pbi::ArenaStringPtr::InternalSwap(&_impl_.red_, &other->_impl_.red_, arena);
  ::_pbi::ArenaStringPtr::InternalSwap(&_impl_.calculation_expr_, &other->_impl_.calculation_expr_, arena);
  ::_pbi::ArenaStringPtr::InternalSwap(&_impl_.warning_expr_, &other->_impl_.warning_expr_, arena);
  ::_pbi::ArenaStringPtr::InternalSwap(&_impl_.critical_expr_, &other->_impl_.critical_expr_, arena);
  ::_pbi::ArenaStringPtr::InternalSwap(&_impl_.recipient_, &other->_impl_.recipient_, arena);
  ::_pbi::ArenaStringPtr::InternalSwap(&_impl_.exec_, &other->_impl_.exec_, arena);
  ::_pbi::ArenaStringPtr::InternalSwap(&_impl_.delay_, &other->_impl_.delay_, arena);
  ::_pbi::ArenaStringPtr::InternalSwap(&_impl_.repeat_, &other->_impl_.repeat_, arena);
  ::_pbi::ArenaStringPtr::InternalSwap(&_impl_.info_, &other->_impl_.info_, arena);
  ::_pbi::ArenaStringPtr::InternalSwap(&_impl_.options_, &other->_impl_.options_, arena);
  ::_pbi::ArenaStringPtr::InternalSwap(&_impl_.host_labels_, &other->_impl_.host_labels_, arena);
  ::_pbi::ArenaStringPtr::InternalSwap(&_impl_.p_db_lookup_dimensions_, &other->_impl_.p_db_lookup_dimensions_, arena);
  ::_pbi::ArenaStringPtr::InternalSwap(&_impl_.p_db_lookup_method_, &other->_impl_.p_db_lookup_method_, arena);
  ::google::protobuf::internal::memswap<
      PROTOBUF_FIELD_OFFSET(AlarmConfiguration, _impl_.p_db_lookup_before_)
      + sizeof(AlarmConfiguration::_impl_.p_db_lookup_before_)
      - PROTOBUF_FIELD_OFFSET(AlarmConfiguration, _impl_.p_db_lookup_after_)>(
          reinterpret_cast<char*>(&_impl_.p_db_lookup_after_),
          reinterpret_cast<char*>(&other->_impl_.p_db_lookup_after_));
  ::_pbi::ArenaStringPtr::InternalSwap(&_impl_.p_db_lookup_options_, &other->_impl_.p_db_lookup_options_, arena);
  ::_pbi::ArenaStringPtr::InternalSwap(&_impl_.chart_labels_, &other->_impl_.chart_labels_, arena);
  ::_pbi::ArenaStringPtr::InternalSwap(&_impl_.summary_, &other->_impl_.summary_, arena);
  swap(_impl_.p_update_every_, other->_impl_.p_update_every_);
}

::google::protobuf::Metadata AlarmConfiguration::GetMetadata() const {
  return ::google::protobuf::Message::GetMetadataImpl(GetClassData()->full());
}
// @@protoc_insertion_point(namespace_scope)
}  // namespace v1
}  // namespace alarms
namespace google {
namespace protobuf {
}  // namespace protobuf
}  // namespace google
// @@protoc_insertion_point(global_scope)
PROTOBUF_ATTRIBUTE_INIT_PRIORITY2 static ::std::false_type
    _static_init2_ [[maybe_unused]] =
        (::_pbi::AddDescriptors(&descriptor_table_alarm_2fv1_2fconfig_2eproto),
         ::std::false_type{});
#include "google/protobuf/port_undef.inc"
